@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,7 +62,9 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         FMLA_STYPE
+#define YYLTYPE         FMLA_LTYPE
 /* Substitute the variable and function names.  */
 #define yyparse         fmla_parse
 #define yylex           fmla_lex
@@ -70,34 +76,16 @@
 #define yychar          fmla_char
 #define yylloc          fmla_lloc
 
-/* Copy the first part of user declarations.  */
-#line 1 "formula.y" /* yacc.c:339  */
-
-/* Copyright (C) 2006-2011, Ondra Kamenik */
-
-#include <cstdio>
-
-#include "location.h"
-#include "formula_parser.h" 
-#include "formula_tab.hh"
-
-	void fmla_error(const char*);
-	int fmla_lex(void);
-	extern int fmla_lineno;
-	extern ogp::FormulaParser* fparser;
-	extern YYLTYPE fmla_lloc;
-
-  //  static void print_token_value (FILE *, int, YYSTYPE);
-  //  #define YYPRINT(file, type, value) print_token_value (file, type, value)
-
-
-#line 95 "formula_tab.cc" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -114,17 +102,32 @@
 #ifndef YY_FMLA_FORMULA_TAB_HH_INCLUDED
 # define YY_FMLA_FORMULA_TAB_HH_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+#ifndef FMLA_DEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define FMLA_DEBUG 1
+#  else
+#   define FMLA_DEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define FMLA_DEBUG 0
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined FMLA_DEBUG */
+#if FMLA_DEBUG
 extern int fmla_debug;
 #endif
+/* "%code requires" blocks.  */
+#line 23 "formula.yy" /* yacc.c:352  */
+
+#include "location.hh"
+#define FMLA_LTYPE ogp::location_type
+
+#line 126 "formula_tab.cc" /* yacc.c:352  */
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef FMLA_TOKENTYPE
+# define FMLA_TOKENTYPE
+  enum fmla_tokentype
   {
     EQUAL_SIGN = 258,
     YPLUS = 259,
@@ -149,48 +152,57 @@ extern int fmla_debug;
 #endif
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined FMLA_STYPE && ! defined FMLA_STYPE_IS_DECLARED
 
-union YYSTYPE
+union FMLA_STYPE
 {
-#line 21 "formula.y" /* yacc.c:355  */
+#line 39 "formula.yy" /* yacc.c:352  */
 
-	char* string;
-	double dvalue;
-	int integer;
+  char* string;
+  double dvalue;
+  int integer;
 
-#line 163 "formula_tab.cc" /* yacc.c:355  */
+#line 166 "formula_tab.cc" /* yacc.c:352  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union FMLA_STYPE FMLA_STYPE;
+# define FMLA_STYPE_IS_TRIVIAL 1
+# define FMLA_STYPE_IS_DECLARED 1
 #endif
 
 /* Location type.  */
-#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
-typedef struct YYLTYPE YYLTYPE;
-struct YYLTYPE
+#if ! defined FMLA_LTYPE && ! defined FMLA_LTYPE_IS_DECLARED
+typedef struct FMLA_LTYPE FMLA_LTYPE;
+struct FMLA_LTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
 };
-# define YYLTYPE_IS_DECLARED 1
-# define YYLTYPE_IS_TRIVIAL 1
+# define FMLA_LTYPE_IS_DECLARED 1
+# define FMLA_LTYPE_IS_TRIVIAL 1
 #endif
 
 
-extern YYSTYPE fmla_lval;
-extern YYLTYPE fmla_lloc;
+extern FMLA_STYPE fmla_lval;
+extern FMLA_LTYPE fmla_lloc;
 int fmla_parse (void);
 
 #endif /* !YY_FMLA_FORMULA_TAB_HH_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 194 "formula_tab.cc" /* yacc.c:358  */
+/* Unqualified %code blocks.  */
+#line 29 "formula.yy" /* yacc.c:355  */
+
+#include "formula_parser.hh" 
+#include <string>
+
+void fmla_error(std::string);
+int fmla_lex();
+extern ogp::FormulaParser* fparser;
+
+#line 206 "formula_tab.cc" /* yacc.c:355  */
 
 #ifdef short
 # undef short
@@ -211,13 +223,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -229,7 +241,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -265,15 +277,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -281,7 +284,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -371,8 +374,8 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL \
-             && defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined FMLA_LTYPE_IS_TRIVIAL && FMLA_LTYPE_IS_TRIVIAL \
+             && defined FMLA_STYPE_IS_TRIVIAL && FMLA_STYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -445,16 +448,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  69
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   276
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -487,17 +490,17 @@ static const yytype_uint8 yytranslate[] =
       15,    16,    17,    18,    19,    20,    21
 };
 
-#if YYDEBUG
+#if FMLA_DEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    42,    42,    43,    47,    47,    49,    51,    55,    56,
-      57,    58,    59,    60,    61,    62,    63,    64,    65,    66,
-      67,    68,    69,    70,    71,    72,    73
+       0,    61,    61,    62,    66,    66,    68,    70,    74,    75,
+      76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
+      86,    87,    88,    89,    90,    91,    92
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 1
+#if FMLA_DEBUG || YYERROR_VERBOSE || 1
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -655,22 +658,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -705,7 +708,7 @@ while (0)
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if FMLA_DEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -724,15 +727,15 @@ do {                                            \
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+# if defined FMLA_LTYPE_IS_TRIVIAL && FMLA_LTYPE_IS_TRIVIAL
 
 /* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
 
 YY_ATTRIBUTE_UNUSED
-static unsigned
+static int
 yy_location_print_ (FILE *yyo, YYLTYPE const * const yylocp)
 {
-  unsigned res = 0;
+  int res = 0;
   int end_col = 0 != yylocp->last_column ? yylocp->last_column - 1 : 0;
   if (0 <= yylocp->first_line)
     {
@@ -775,40 +778,40 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (yylocationp);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  YY_LOCATION_PRINT (yyoutput, *yylocationp);
-  YYFPRINTF (yyoutput, ": ");
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp);
-  YYFPRINTF (yyoutput, ")");
+  YY_LOCATION_PRINT (yyo, *yylocationp);
+  YYFPRINTF (yyo, ": ");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, yylocationp);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -842,7 +845,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -853,7 +856,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int yyrule
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                        , &(yylsp[(yyi + 1) - (yynrhs)])                       );
       YYFPRINTF (stderr, "\n");
     }
@@ -868,12 +871,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !FMLA_DEBUG */
 # define YYDPRINTF(Args)
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !FMLA_DEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -957,7 +960,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -975,7 +981,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1053,10 +1059,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1068,6 +1074,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1079,9 +1086,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1143,7 +1151,7 @@ int yychar;
 YYSTYPE yylval;
 /* Location data for the lookahead symbol.  */
 YYLTYPE yylloc
-# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+# if defined FMLA_LTYPE_IS_TRIVIAL && FMLA_LTYPE_IS_TRIVIAL
   = { 1, 1, 1, 1 }
 # endif
 ;
@@ -1226,23 +1234,31 @@ yyparse (void)
   yylsp[0] = yylloc;
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1260,15 +1276,11 @@ yyparse (void)
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yyls1, yysize * sizeof (*yylsp),
                     &yystacksize);
-
-        yyls = yyls1;
         yyss = yyss1;
         yyvs = yyvs1;
+        yyls = yyls1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1285,23 +1297,23 @@ yyparse (void)
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
         YYSTACK_RELOCATE (yyls_alloc, yyls);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
       yylsp = yyls + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1310,11 +1322,11 @@ yyparse (void)
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1387,7 +1399,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1403,145 +1415,146 @@ yyreduce:
      GCC warning that YYVAL may be used uninitialized.  */
   yyval = yyvsp[1-yylen];
 
-  /* Default location.  */
+  /* Default location. */
   YYLLOC_DEFAULT (yyloc, (yylsp - yylen), yylen);
+  yyerror_range[1] = yyloc;
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 3:
-#line 44 "formula.y" /* yacc.c:1646  */
+#line 63 "formula.yy" /* yacc.c:1652  */
     {fparser->add_formula((yyvsp[0].integer));}
-#line 1415 "formula_tab.cc" /* yacc.c:1646  */
+#line 1428 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 6:
-#line 50 "formula.y" /* yacc.c:1646  */
-    {fparser->add_formula(fparser->add_binary(ogp::MINUS,(yyvsp[-3].integer),(yyvsp[-1].integer)));}
-#line 1421 "formula_tab.cc" /* yacc.c:1646  */
+#line 69 "formula.yy" /* yacc.c:1652  */
+    {fparser->add_formula(fparser->add_binary(ogp::code_t::MINUS,(yyvsp[-3].integer),(yyvsp[-1].integer)));}
+#line 1434 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 7:
-#line 52 "formula.y" /* yacc.c:1646  */
+#line 71 "formula.yy" /* yacc.c:1652  */
     {fparser->add_formula((yyvsp[-1].integer));}
-#line 1427 "formula_tab.cc" /* yacc.c:1646  */
+#line 1440 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 8:
-#line 55 "formula.y" /* yacc.c:1646  */
+#line 74 "formula.yy" /* yacc.c:1652  */
     { (yyval.integer) = (yyvsp[-1].integer);}
-#line 1433 "formula_tab.cc" /* yacc.c:1646  */
+#line 1446 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 56 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_binary(ogp::PLUS,(yyvsp[-2].integer),(yyvsp[0].integer));}
-#line 1439 "formula_tab.cc" /* yacc.c:1646  */
+#line 75 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_binary(ogp::code_t::PLUS,(yyvsp[-2].integer),(yyvsp[0].integer));}
+#line 1452 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 57 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_binary(ogp::MINUS,(yyvsp[-2].integer),(yyvsp[0].integer));}
-#line 1445 "formula_tab.cc" /* yacc.c:1646  */
+#line 76 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_binary(ogp::code_t::MINUS,(yyvsp[-2].integer),(yyvsp[0].integer));}
+#line 1458 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 11:
-#line 58 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_binary(ogp::TIMES,(yyvsp[-2].integer),(yyvsp[0].integer));}
-#line 1451 "formula_tab.cc" /* yacc.c:1646  */
+#line 77 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_binary(ogp::code_t::TIMES,(yyvsp[-2].integer),(yyvsp[0].integer));}
+#line 1464 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 59 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_binary(ogp::DIVIDE,(yyvsp[-2].integer),(yyvsp[0].integer));}
-#line 1457 "formula_tab.cc" /* yacc.c:1646  */
+#line 78 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_binary(ogp::code_t::DIVIDE,(yyvsp[-2].integer),(yyvsp[0].integer));}
+#line 1470 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 13:
-#line 60 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_binary(ogp::POWER,(yyvsp[-2].integer),(yyvsp[0].integer));}
-#line 1463 "formula_tab.cc" /* yacc.c:1646  */
+#line 79 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_binary(ogp::code_t::POWER,(yyvsp[-2].integer),(yyvsp[0].integer));}
+#line 1476 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 14:
-#line 61 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::UMINUS,(yyvsp[0].integer));}
-#line 1469 "formula_tab.cc" /* yacc.c:1646  */
+#line 80 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::UMINUS,(yyvsp[0].integer));}
+#line 1482 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 15:
-#line 62 "formula.y" /* yacc.c:1646  */
+#line 81 "formula.yy" /* yacc.c:1652  */
     {(yyval.integer) = (yyvsp[0].integer);}
-#line 1475 "formula_tab.cc" /* yacc.c:1646  */
+#line 1488 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 63 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::SIN,(yyvsp[-1].integer));}
-#line 1481 "formula_tab.cc" /* yacc.c:1646  */
+#line 82 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::SIN,(yyvsp[-1].integer));}
+#line 1494 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 17:
-#line 64 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::COS,(yyvsp[-1].integer));}
-#line 1487 "formula_tab.cc" /* yacc.c:1646  */
+#line 83 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::COS,(yyvsp[-1].integer));}
+#line 1500 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 65 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::TAN,(yyvsp[-1].integer));}
-#line 1493 "formula_tab.cc" /* yacc.c:1646  */
+#line 84 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::TAN,(yyvsp[-1].integer));}
+#line 1506 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 66 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::EXP,(yyvsp[-1].integer));}
-#line 1499 "formula_tab.cc" /* yacc.c:1646  */
+#line 85 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::EXP,(yyvsp[-1].integer));}
+#line 1512 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 20:
-#line 67 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::LOG,(yyvsp[-1].integer));}
-#line 1505 "formula_tab.cc" /* yacc.c:1646  */
+#line 86 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::LOG,(yyvsp[-1].integer));}
+#line 1518 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 21:
-#line 68 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::SQRT,(yyvsp[-1].integer));}
-#line 1511 "formula_tab.cc" /* yacc.c:1646  */
+#line 87 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::SQRT,(yyvsp[-1].integer));}
+#line 1524 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 22:
-#line 69 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::ERF,(yyvsp[-1].integer));}
-#line 1517 "formula_tab.cc" /* yacc.c:1646  */
+#line 88 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::ERF,(yyvsp[-1].integer));}
+#line 1530 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 23:
-#line 70 "formula.y" /* yacc.c:1646  */
-    {(yyval.integer)=fparser->add_unary(ogp::ERFC,(yyvsp[-1].integer));}
-#line 1523 "formula_tab.cc" /* yacc.c:1646  */
+#line 89 "formula.yy" /* yacc.c:1652  */
+    {(yyval.integer)=fparser->add_unary(ogp::code_t::ERFC,(yyvsp[-1].integer));}
+#line 1536 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 24:
-#line 71 "formula.y" /* yacc.c:1646  */
+#line 90 "formula.yy" /* yacc.c:1652  */
     {(yyval.integer)=fparser->add_derivative((yyvsp[-3].integer), fparser->add_nulary((yyvsp[-1].string)));}
-#line 1529 "formula_tab.cc" /* yacc.c:1646  */
+#line 1542 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 25:
-#line 72 "formula.y" /* yacc.c:1646  */
+#line 91 "formula.yy" /* yacc.c:1652  */
     {(yyval.integer)=fparser->add_nulary((yyvsp[0].string));}
-#line 1535 "formula_tab.cc" /* yacc.c:1646  */
+#line 1548 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
   case 26:
-#line 73 "formula.y" /* yacc.c:1646  */
+#line 92 "formula.yy" /* yacc.c:1652  */
     {(yyval.integer)=fparser->add_nulary((yyvsp[0].string));}
-#line 1541 "formula_tab.cc" /* yacc.c:1646  */
+#line 1554 "formula_tab.cc" /* yacc.c:1652  */
     break;
 
 
-#line 1545 "formula_tab.cc" /* yacc.c:1646  */
+#line 1558 "formula_tab.cc" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1567,14 +1580,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1657,14 +1669,11 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
-
-  yyerror_range[1] = yylsp[1-yylen];
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
   YYPOPSTACK (yylen);
@@ -1730,6 +1739,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1737,6 +1747,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1747,6 +1758,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1776,18 +1791,11 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 76 "formula.y" /* yacc.c:1906  */
+#line 95 "formula.yy" /* yacc.c:1918  */
 
 
-void fmla_error(const char* s)
+void
+fmla_error(std::string s)
 {
-	fparser->error(s);
+  fparser->error(std::move(s));
 }
-
-/*
-static void print_token_value(FILE* file, int type, YYSTYPE value)
-{
-	if (type == NAME)
-		fprintf(file, "%s", value.string);
-}
-*/
