@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,7 +62,9 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         DYNGLOB_STYPE
+#define YYLTYPE         DYNGLOB_LTYPE
 /* Substitute the variable and function names.  */
 #define yyparse         dynglob_parse
 #define yylex           dynglob_lex
@@ -70,34 +76,16 @@
 #define yychar          dynglob_char
 #define yylloc          dynglob_lloc
 
-/* Copy the first part of user declarations.  */
-#line 1 "dynglob.y" /* yacc.c:339  */
-
-// Copyright (C) 2006-2011, Ondra Kamenik
-
-#include "parser/cc/location.h"
-#include "dynare_model.h"
-#include "dynglob_tab.hh"
-
-#include <stdio.h>
-
-	void dynglob_error(const char*);
-	int dynglob_lex(void);
-	extern int dynglob_lineno;
-	extern ogdyn::DynareParser* dynare_parser;
-	int symblist_flag;
-
-  //	static void print_token_value1 (FILE *, int, YYSTYPE);
-  //#define YYPRINT(file, type, value) print_token_value1 (file, type, value)
-
-
-#line 95 "dynglob_tab.cc" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -114,17 +102,32 @@
 #ifndef YY_DYNGLOB_DYNGLOB_TAB_HH_INCLUDED
 # define YY_DYNGLOB_DYNGLOB_TAB_HH_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+#ifndef DYNGLOB_DEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define DYNGLOB_DEBUG 1
+#  else
+#   define DYNGLOB_DEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define DYNGLOB_DEBUG 0
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined DYNGLOB_DEBUG */
+#if DYNGLOB_DEBUG
 extern int dynglob_debug;
 #endif
+/* "%code requires" blocks.  */
+#line 23 "dynglob.yy" /* yacc.c:352  */
+
+#include "parser/cc/location.hh"
+#define DYNGLOB_LTYPE ogp::location_type
+
+#line 126 "dynglob_tab.cc" /* yacc.c:352  */
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef DYNGLOB_TOKENTYPE
+# define DYNGLOB_TOKENTYPE
+  enum dynglob_tokentype
   {
     END = 258,
     INITVAL = 259,
@@ -147,48 +150,59 @@ extern int dynglob_debug;
 #endif
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined DYNGLOB_STYPE && ! defined DYNGLOB_STYPE_IS_DECLARED
 
-union YYSTYPE
+union DYNGLOB_STYPE
 {
-#line 21 "dynglob.y" /* yacc.c:355  */
+#line 41 "dynglob.yy" /* yacc.c:352  */
 
-	int integer;
-	char *string;
-	char character;
+  int integer;
+  char *string;
+  char character;
 
-#line 161 "dynglob_tab.cc" /* yacc.c:355  */
+#line 164 "dynglob_tab.cc" /* yacc.c:352  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union DYNGLOB_STYPE DYNGLOB_STYPE;
+# define DYNGLOB_STYPE_IS_TRIVIAL 1
+# define DYNGLOB_STYPE_IS_DECLARED 1
 #endif
 
 /* Location type.  */
-#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
-typedef struct YYLTYPE YYLTYPE;
-struct YYLTYPE
+#if ! defined DYNGLOB_LTYPE && ! defined DYNGLOB_LTYPE_IS_DECLARED
+typedef struct DYNGLOB_LTYPE DYNGLOB_LTYPE;
+struct DYNGLOB_LTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
 };
-# define YYLTYPE_IS_DECLARED 1
-# define YYLTYPE_IS_TRIVIAL 1
+# define DYNGLOB_LTYPE_IS_DECLARED 1
+# define DYNGLOB_LTYPE_IS_TRIVIAL 1
 #endif
 
 
-extern YYSTYPE dynglob_lval;
-extern YYLTYPE dynglob_lloc;
+extern DYNGLOB_STYPE dynglob_lval;
+extern DYNGLOB_LTYPE dynglob_lloc;
 int dynglob_parse (void);
 
 #endif /* !YY_DYNGLOB_DYNGLOB_TAB_HH_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 192 "dynglob_tab.cc" /* yacc.c:358  */
+/* Unqualified %code blocks.  */
+#line 29 "dynglob.yy" /* yacc.c:355  */
+
+#include <string>
+
+#include "dynare_model.hh"
+
+void dynglob_error(std::string);
+int dynglob_lex();
+extern ogdyn::DynareParser* dynare_parser;
+int symblist_flag;
+
+#line 206 "dynglob_tab.cc" /* yacc.c:355  */
 
 #ifdef short
 # undef short
@@ -209,13 +223,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -227,7 +241,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -263,15 +277,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -279,7 +284,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -369,8 +374,8 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL \
-             && defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined DYNGLOB_LTYPE_IS_TRIVIAL && DYNGLOB_LTYPE_IS_TRIVIAL \
+             && defined DYNGLOB_STYPE_IS_TRIVIAL && DYNGLOB_STYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -443,16 +448,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  95
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   274
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -485,20 +490,20 @@ static const yytype_uint8 yytranslate[] =
       15,    16,    17,    18,    19
 };
 
-#if YYDEBUG
+#if DYNGLOB_DEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    38,    38,    40,    42,    46,    46,    48,    48,    48,
-      50,    50,    52,    52,    54,    54,    57,    58,    59,    62,
-      64,    64,    66,    68,    68,    68,    68,    70,    74,    74,
-      76,    76,    78,    78,    80,    80,    80,    80,    82,    86,
-      90,    90,    90,    90,    90,    90,    90,    90,    92,    96,
-      97,   100,   104
+       0,    59,    59,    61,    63,    67,    67,    69,    69,    69,
+      71,    71,    73,    73,    75,    75,    78,    79,    80,    83,
+      85,    85,    87,    89,    89,    89,    89,    91,    95,    95,
+      97,    97,    99,    99,   101,   101,   101,   101,   103,   107,
+     111,   111,   111,   111,   111,   111,   111,   111,   113,   117,
+     118,   121,   125
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 1
+#if DYNGLOB_DEBUG || YYERROR_VERBOSE || 1
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -666,22 +671,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -716,7 +721,7 @@ while (0)
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if DYNGLOB_DEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -735,15 +740,15 @@ do {                                            \
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+# if defined DYNGLOB_LTYPE_IS_TRIVIAL && DYNGLOB_LTYPE_IS_TRIVIAL
 
 /* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
 
 YY_ATTRIBUTE_UNUSED
-static unsigned
+static int
 yy_location_print_ (FILE *yyo, YYLTYPE const * const yylocp)
 {
-  unsigned res = 0;
+  int res = 0;
   int end_col = 0 != yylocp->last_column ? yylocp->last_column - 1 : 0;
   if (0 <= yylocp->first_line)
     {
@@ -786,40 +791,40 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (yylocationp);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  YY_LOCATION_PRINT (yyoutput, *yylocationp);
-  YYFPRINTF (yyoutput, ": ");
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp);
-  YYFPRINTF (yyoutput, ")");
+  YY_LOCATION_PRINT (yyo, *yylocationp);
+  YYFPRINTF (yyo, ": ");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, yylocationp);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -853,7 +858,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -864,7 +869,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int yyrule
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                        , &(yylsp[(yyi + 1) - (yynrhs)])                       );
       YYFPRINTF (stderr, "\n");
     }
@@ -879,12 +884,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !DYNGLOB_DEBUG */
 # define YYDPRINTF(Args)
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !DYNGLOB_DEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -968,7 +973,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -986,7 +994,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1064,10 +1072,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1079,6 +1087,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1090,9 +1099,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1154,7 +1164,7 @@ int yychar;
 YYSTYPE yylval;
 /* Location data for the lookahead symbol.  */
 YYLTYPE yylloc
-# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+# if defined DYNGLOB_LTYPE_IS_TRIVIAL && DYNGLOB_LTYPE_IS_TRIVIAL
   = { 1, 1, 1, 1 }
 # endif
 ;
@@ -1237,23 +1247,31 @@ yyparse (void)
   yylsp[0] = yylloc;
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1271,15 +1289,11 @@ yyparse (void)
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yyls1, yysize * sizeof (*yylsp),
                     &yystacksize);
-
-        yyls = yyls1;
         yyss = yyss1;
         yyvs = yyvs1;
+        yyls = yyls1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1296,23 +1310,23 @@ yyparse (void)
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
         YYSTACK_RELOCATE (yyls_alloc, yyls);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
       yylsp = yyls + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1321,11 +1335,11 @@ yyparse (void)
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1398,7 +1412,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1414,118 +1428,119 @@ yyreduce:
      GCC warning that YYVAL may be used uninitialized.  */
   yyval = yyvsp[1-yylen];
 
-  /* Default location.  */
+  /* Default location. */
   YYLLOC_DEFAULT (yyloc, (yylsp - yylen), yylen);
+  yyerror_range[1] = yyloc;
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 2:
-#line 38 "dynglob.y" /* yacc.c:1646  */
+#line 59 "dynglob.yy" /* yacc.c:1652  */
     {
 	dynare_parser->set_paramset_pos((yylsp[-2]).off, (yylsp[-1]).off);}
-#line 1427 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1442 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 3:
-#line 40 "dynglob.y" /* yacc.c:1646  */
+#line 61 "dynglob.yy" /* yacc.c:1652  */
     {
 	dynare_parser->set_paramset_pos(0, 0);}
-#line 1434 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1449 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 4:
-#line 42 "dynglob.y" /* yacc.c:1646  */
+#line 63 "dynglob.yy" /* yacc.c:1652  */
     {
 	dynare_parser->set_paramset_pos((yylsp[-3]).off, (yylsp[-2]).off);}
-#line 1441 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1456 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 50 "dynglob.y" /* yacc.c:1646  */
+#line 71 "dynglob.yy" /* yacc.c:1652  */
     {symblist_flag=1;}
-#line 1447 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1462 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 52 "dynglob.y" /* yacc.c:1646  */
+#line 73 "dynglob.yy" /* yacc.c:1652  */
     {symblist_flag=2;}
-#line 1453 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1468 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 14:
-#line 54 "dynglob.y" /* yacc.c:1646  */
+#line 75 "dynglob.yy" /* yacc.c:1652  */
     {symblist_flag=3;}
-#line 1459 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1474 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 57 "dynglob.y" /* yacc.c:1646  */
+#line 78 "dynglob.yy" /* yacc.c:1652  */
     {dynare_parser->add_name((yyvsp[0].string),symblist_flag);}
-#line 1465 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1480 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 17:
-#line 58 "dynglob.y" /* yacc.c:1646  */
+#line 79 "dynglob.yy" /* yacc.c:1652  */
     {dynare_parser->add_name((yyvsp[0].string),symblist_flag);}
-#line 1471 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1486 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 59 "dynglob.y" /* yacc.c:1646  */
+#line 80 "dynglob.yy" /* yacc.c:1652  */
     {dynare_parser->add_name((yyvsp[0].string),symblist_flag);}
-#line 1477 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1492 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 27:
-#line 70 "dynglob.y" /* yacc.c:1646  */
+#line 91 "dynglob.yy" /* yacc.c:1652  */
     {
 	dynare_parser->set_model_pos((yylsp[-2]).off, (yylsp[-1]).off);
 }
-#line 1485 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1500 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 38:
-#line 82 "dynglob.y" /* yacc.c:1646  */
+#line 103 "dynglob.yy" /* yacc.c:1652  */
     {
 	dynare_parser->set_initval_pos((yylsp[-2]).off, (yylsp[-1]).off);
 }
-#line 1493 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1508 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 39:
-#line 86 "dynglob.y" /* yacc.c:1646  */
+#line 107 "dynglob.yy" /* yacc.c:1652  */
     {
 	dynare_parser->set_vcov_pos((yylsp[-2]).off, (yylsp[-1]).off);
 }
-#line 1501 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1516 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 48:
-#line 92 "dynglob.y" /* yacc.c:1646  */
+#line 113 "dynglob.yy" /* yacc.c:1652  */
     {
     dynare_parser->set_order_pos((yylsp[-1]).off, (yylsp[0]).off);
 }
-#line 1509 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1524 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 51:
-#line 100 "dynglob.y" /* yacc.c:1646  */
+#line 121 "dynglob.yy" /* yacc.c:1652  */
     {
 	dynare_parser->set_pl_objective_pos((yylsp[-1]).off, (yylsp[0]).off);
 }
-#line 1517 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1532 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
   case 52:
-#line 104 "dynglob.y" /* yacc.c:1646  */
+#line 125 "dynglob.yy" /* yacc.c:1652  */
     {
 	dynare_parser->set_pl_discount_pos((yylsp[-1]).off, (yylsp[0]).off);
 }
-#line 1525 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1540 "dynglob_tab.cc" /* yacc.c:1652  */
     break;
 
 
-#line 1529 "dynglob_tab.cc" /* yacc.c:1646  */
+#line 1544 "dynglob_tab.cc" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1551,14 +1566,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1641,14 +1655,11 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
-
-  yyerror_range[1] = yylsp[1-yylen];
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
   YYPOPSTACK (yylen);
@@ -1714,6 +1725,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1721,6 +1733,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1731,6 +1744,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1760,20 +1777,11 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 108 "dynglob.y" /* yacc.c:1906  */
+#line 129 "dynglob.yy" /* yacc.c:1918  */
 
 
-void dynglob_error(const char* mes)
+void
+dynglob_error(std::string mes)
 {
-	dynare_parser->error(mes);
+  dynare_parser->error(mes);
 }
-
-/*
-static void print_token_value1(FILE* file, int type, YYSTYPE value)
-{
-	if (type == NAME)
-		fprintf(file, "%s", value.string);
-	if (type == CHARACTER)
-		fprintf(file, "%c", value.character);
-}
-*/
