@@ -40,7 +40,7 @@ irf = icc1+(options_.periods-1)*ny ;
 d1 = zeros(options_.periods*ny,1) ;
 
 ofs = (((options_.periods-1)*ny+1)-1)*jcf*8 ;
-junk = fseek(fid,ofs,-1) ;
+[~] = fseek(fid,ofs,-1) ;
 c = fread(fid,[jcf,ny],'float64')';
 
 d1(ir) = c(:,jcf) ;
@@ -52,7 +52,7 @@ while i <= M_.maximum_lead || i <= options_.periods
     irf1 = selif(irf,irf<=options_.periods*ny) ;
 
     ofs = (((options_.periods-i)*ny+1)-1)*jcf*8 ;
-    junk = fseek(fid,ofs,-1) ;
+    [~] = fseek(fid,ofs,-1) ;
     c = fread(fid,[jcf,ny],'float64')' ;
 
     d1(ir) = c(:,jcf) - c(:,1:size(irf1,1))*d1(irf1) ;
@@ -64,7 +64,7 @@ end
 while i <= options_.periods
 
     ofs = (((options_.periods-i)*ny+1)-1)*jcf*8 ;
-    junk = fseek(fid,ofs,-1) ;
+    [~] = fseek(fid,ofs,-1) ;
     c = fread(fid,[jcf,ny],'float64')' ;
 
     d1(ir) = c(:,jcf)-c(:,icf)*d1(irf) ;
