@@ -54,7 +54,7 @@ oo_.mean = m;
 oo_.var = oo_.gamma_y{1};
 
 ME_present=0;
-if ~all(M_.H==0)
+if ~all(diag(M_.H)==0)
     if isoctave || matlab_ver_less_than('8.1')
         [observable_pos_requested_vars,index_subset,index_observables]=intersect_stable(ivar,options_.varobs_id);
     else
