@@ -1,53 +1,27 @@
-function [dr,info] = dyn_first_order_solver(jacobia,DynareModel,dr,DynareOptions,task)
+function [dr, info] = dyn_first_order_solver(jacobia, DynareModel, dr, DynareOptions, task)
 
-%@info:
-%! @deftypefn {Function File} {[@var{dr},@var{info}] =} dyn_first_order_solver (@var{jacobia},@var{DynareModel},@var{dr},@var{DynareOptions},@var{task})
-%! @anchor{dyn_first_order_solver}
-%! @sp 1
-%! Computes the first order reduced form of the DSGE model
-%! @sp 2
-%! @strong{Inputs}
-%! @sp 1
-%! @table @ @var
-%! @item jacobia
-%! Matrix containing the Jacobian of the model
-%! @item DynareModel
-%! Matlab's structure describing the model (initialized by @code{dynare}).
-%! @item dr
-%! Matlab's structure describing the reduced form solution of the model.
-%! @item qz_criterium
-%! Double containing the criterium to separate explosive from stable eigenvalues
-%! @end table
-%! @sp 2
-%! @strong{Outputs}
-%! @sp 1
-%! @table @ @var
-%! @item dr
-%! Matlab's structure describing the reduced form solution of the model.
-%! @item info
-%! Integer scalar, error code.
-%! @sp 1
-%! @table @ @code
-%! @item info==0
-%! No error.
-%! @item info==1
-%! The model doesn't determine the current variables uniquely.
-%! @item info==2
-%! MJDGGES returned an error code.
-%! @item info==3
-%! Blanchard & Kahn conditions are not satisfied: no stable equilibrium.
-%! @item info==4
-%! Blanchard & Kahn conditions are not satisfied: indeterminacy.
-%! @item info==5
-%! Blanchard & Kahn conditions are not satisfied: indeterminacy due to rank failure.
-%! @item info==7
-%! One of the generalized eigenvalues is close to 0/0
-%! @end table
-%! @end table
-%! @end deftypefn
-%@eod:
+% Computes the first order reduced form of a DSGE model.
+%
+% INPUTS
+% - jacobia       [double]    matrix, the jacobian of the dynamic model.
+% - DynareModel   [struct]    Matlab's structre describing the model, M_ global.
+% - dr            [struct]    Matlab's structure describing the reduced form model.
+% - DynareOptions [struct]    Matlab's structure containing the current state of the options, oo_ global.
+% - task          [integer]   scalar, if task = 0 then decision rules are computed and if task = 1 then only eigenvales are computed.
+%
+% OUTPUTS
+% - dr            [struct]    Matlab's structure describing the reduced form model.
+% - info          [integer]   scalar, error code. Possible values are:
+%
+%                                     info=0 -> no error,
+%                                     info=1 -> the model doesn't determine the current variables uniquely,
+%                                     info=2 -> mjdgges dll returned an error,
+%                                     info=3 -> Blanchard and Kahn conditions are not satisfied: no stable equilibrium,
+%                                     info=4 -> Blanchard and Kahn conditions are not satisfied: indeterminacy,
+%                                     info=5 -> Blanchard and Kahn conditions are not satisfied: indeterminacy due to rank failure,
+%                                     info=7 -> One of the eigenvalues is close to 0/0 (infinity of complex solutions)
 
-% Copyright (C) 2001-2017 Dynare Team
+% Copyright (C) 2001-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -133,7 +107,7 @@ if isempty(reorder_jacobian_columns)
 
     npred0 = nnz(lead_lag_incidence(maximum_lag+1,no_both_lag_id));
     index_0m = indexi_0+nstatic+(1:npred0);
-    nfwrd0 = nnz(lead_lag_incidence(2,lead_id));
+    nfwrd0 = nnz(lead_lag_incidence(maximum_lag+1,lead_id));
     index_0p = indexi_0+nstatic+npred0+(1:nfwrd0);
     index_m  = 1:(npred+nboth);
     index_p  = npred+nboth+n_current+(1:nfwrd+nboth);
@@ -150,7 +124,7 @@ if isempty(reorder_jacobian_columns)
                                                       nsfwrd)))];
     index_e2 = npred+nboth+(1:nboth);
 
-    [junk,cols_b] = find(lead_lag_incidence(maximum_lag+1, order_var));
+    [~,cols_b] = find(lead_lag_incidence(maximum_lag+1, order_var));
 
     reorder_jacobian_columns = [nonzeros(lead_lag_incidence(:,order_var)'); ...
                         nz+(1:exo_nbr)'];
@@ -164,7 +138,7 @@ dr.state_var = state_var;
 jacobia = jacobia(:,reorder_jacobian_columns);
 
 if nstatic > 0
-    [Q, junk] = qr(jacobia(:,index_s));
+    [Q, ~] = qr(jacobia(:,index_s));
     aa = Q'*jacobia;
 else
     aa = jacobia;
@@ -193,7 +167,7 @@ if task ~= 1 && (DynareOptions.dr_cycle_reduction || DynareOptions.dr_logarithmi
     A1 = [aa(row_indx,index_m ) zeros(ndynamic,nfwrd)];
     B1 = [aa(row_indx,index_0m) aa(row_indx,index_0p) ];
     C1 = [zeros(ndynamic,npred) aa(row_indx,index_p)];
-    if DynareOptions.dr_cycle_reduction == 1
+    if DynareOptions.dr_cycle_reduction
         [ghx, info] = cycle_reduction(A1, B1, C1, DynareOptions.dr_cycle_reduction_tol);
     else
         [ghx, info] = logarithmic_reduction(C1, B1, A1, DynareOptions.dr_logarithmic_reduction_tol, DynareOptions.dr_logarithmic_reduction_maxiter);
@@ -228,15 +202,17 @@ else
         return
     end
 
+    dr.sdim = sdim;                      % Number of stable eigenvalues.
+    dr.edim = length(dr.eigval)-sdim;    % Number of exposive eigenvalues.
+
     nba = nd-sdim;
 
-    if task == 1
+    if task==1
         if rcond(w(npred+nboth+1:end,npred+nboth+1:end)) < 1e-9
             dr.full_rank = 0;
         else
             dr.full_rank = 1;
         end
-        return
     end
 
     if nba ~= nsfwrd
@@ -251,8 +227,11 @@ else
         info(2) = temp'*temp;
         return
     end
+
+    if task==1, return, end
+
     %First order approximation
-    indx_stable_root = 1: (nd - nsfwrd);     %=> index of stable roots
+    indx_stable_root = 1: (nd - nsfwrd);         %=> index of stable roots
     indx_explosive_root = npred + nboth + 1:nd;  %=> index of explosive roots
                                                  % derivatives with respect to dynamic state variables
                                                  % forward variables
@@ -318,7 +297,7 @@ end
 dr.ghx = ghx;
 dr.ghu = ghu;
 
-if DynareOptions.aim_solver ~= 1 && DynareOptions.use_qzdiv
+if DynareOptions.aim_solver ~= 1
     % Necessary when using Sims' routines for QZ
     dr.ghx = real(ghx);
     dr.ghu = real(ghu);
