@@ -121,10 +121,15 @@ if options_.steadystate_flag
                         oo.exo_det_steady_state], ...
                                                   M,options_,~options_.steadystate.nocheck);
     if any(imag(x(1:M.orig_endo_nbr))) %return with penalty
-        resids=1+sum(abs(imag(x(1:M.orig_endo_nbr)))); %return with penalty
+        resids=ones(inst_nbr,1)+sum(abs(imag(x(1:M.orig_endo_nbr)))); %return with penalty
         steady_state=NaN(endo_nbr,1);
         return
     end
+    if check %return 
+        resids=ones(inst_nbr,1)+sum(abs(x(1:M.orig_endo_nbr))); %return with penalty
+        steady_state=NaN(endo_nbr,1);
+        return        
+    end
 
 end
 
