@@ -48,8 +48,10 @@ else
 end
 if strcmp(caller_file_name,'solve_stacked_problem.m')
     tolf = options.dynatol.f;
+    tolx = options.dynatol.x;
 else
     tolf = options.solve_tolf;
+    tolx = options.solve_tolx;
 end
 
 if strcmp(caller_file_name,'dyn_ramsey_static.m')
@@ -216,11 +218,11 @@ if options.solve_algo == 0
     end
 elseif options.solve_algo == 1
     [x,info]=solve1(func,x,1:nn,1:nn,jacobian_flag,options.gstep, ...
-                    tolf,options.solve_tolx, ...
+                    tolf,tolx, ...
                     maxit,options.debug,varargin{:});
 elseif options.solve_algo == 9
     [x,info]=trust_region(func,x,1:nn,1:nn,jacobian_flag,options.gstep, ...
-                          tolf,options.solve_tolx, ...
+                          tolf,tolx, ...
                           maxit,options.debug,varargin{:});
 elseif options.solve_algo == 2 || options.solve_algo == 4
 
@@ -252,7 +254,7 @@ elseif options.solve_algo == 2 || options.solve_algo == 4
         end
         [x,info]=solver(func,x,j1(r(i):r(i+1)-1),j2(r(i):r(i+1)-1),jacobian_flag, ...
                         options.gstep, ...
-                        tolf,options.solve_tolx, ...
+                        tolf,tolx, ...
                         maxit,options.debug,varargin{:});
         if info
             return
@@ -261,7 +263,7 @@ elseif options.solve_algo == 2 || options.solve_algo == 4
     fvec = feval(func,x,varargin{:});
     if max(abs(fvec)) > tolf
         [x,info]=solver(func,x,1:nn,1:nn,jacobian_flag, ...
-                        options.gstep, tolf,options.solve_tolx, ...
+                        options.gstep, tolf,tolx, ...
                         maxit,options.debug,varargin{:});
     end
 elseif options.solve_algo == 3
