@@ -23,7 +23,7 @@ if options.block && ~options.bytecode
         ss = x;
         if M.block_structure_stat.block(b).Simulation_Type ~= 1 && ...
                 M.block_structure_stat.block(b).Simulation_Type ~= 2
-            if options.solve_algo <= 4
+            if options.solve_algo <= 4 || options.solve_algo >= 9
                 [y, check] = dynare_solve('block_mfs_steadystate', ...
                                           ss(M.block_structure_stat.block(b).variable), ...
                                           options, b, ss, exo, params, M);
