@@ -40,40 +40,39 @@ if debug
     save ep_test_1.mat endo_simul exo_simul
 end
 
-if bytecode_flag && ~ep.stochastic.order
-    [flag, tmp] = bytecode('dynamic', endo_simul, exo_simul, M_.params, endo_simul, periods);
-else
-    flag = true;
+if bytecode_flag && order > 0
+    error('Option order > 0 of extended_path command is not compatible with bytecode option.')
+end
+if options.block && order > 0
+    error('Option order > 0 of extended_path command is not compatible with block option.')
 end
 
-if flag
-    if order == 0
-        options.periods = periods;
-        options.block = pfm.block;
-        oo.endo_simul = endo_simul;
-        oo.exo_simul = exo_simul;
-        oo.steady_state = steady_state;
-        options.bytecode = bytecode_flag;
-        options.lmmcp = olmmcp;
-        options.solve_algo = solve_algo;
-        options.stack_solve_algo = stack_solve_algo;
-        tmp = perfect_foresight_solver_core(M, options, oo);
-        if ~tmp.deterministic_simulation.status
-            info_convergence = false;
-        else
-            info_convergence = true;
-        end
+if order == 0
+    options.periods = periods;
+    options.block = pfm.block;
+    oo.endo_simul = endo_simul;
+    oo.exo_simul = exo_simul;
+    oo.steady_state = steady_state;
+    options.bytecode = bytecode_flag;
+    options.lmmcp = olmmcp;
+    options.solve_algo = solve_algo;
+    options.stack_solve_algo = stack_solve_algo;
+    tmp = perfect_foresight_solver_core(M, options, oo);
+    if ~tmp.deterministic_simulation.status
+        info_convergence = false;
     else
-        switch(algo)
-          case 0
-            [flag, tmp.endo_simul] = ...
-                solve_stochastic_perfect_foresight_model(endo_simul, exo_simul, pfm, ep.stochastic.quadrature.nodes, ep.stochastic.order);
-          case 1
-            [flag, tmp.endo_simul] = ...
-                solve_stochastic_perfect_foresight_model_1(endo_simul, exo_simul, options, pfm, ep.stochastic.order);
-        end
-        info_convergence = ~flag;
+        info_convergence = true;
     end
+else
+    switch(algo)
+        case 0
+            [flag, tmp.endo_simul] = ...
+            solve_stochastic_perfect_foresight_model(endo_simul, exo_simul, pfm, ep.stochastic.quadrature.nodes, ep.stochastic.order);
+        case 1
+            [flag, tmp.endo_simul] = ...
+            solve_stochastic_perfect_foresight_model_1(endo_simul, exo_simul, options, pfm, ep.stochastic.order);
+    end
+    info_convergence = ~flag;
 end
 
 if ~info_convergence && ~options.no_homotopy
@@ -86,4 +85,4 @@ else
     y = NaN(size(endo_nbr,1));
 end
 
-endogenousvariablespaths = tmp.endo_simul;
\ No newline at end of file
+endogenousvariablespaths = tmp.endo_simul;
