@@ -1,10 +1,16 @@
-function lpkern = evaluate_posterior_kernel(parameters,llik)
-% Evaluate the prior density at parameters.
+function lpkern = evaluate_posterior_kernel(parameters,M_,estim_params_,oo_,options_,bayestopt_,llik)
+% Evaluate the evaluate_posterior_kernel at parameters.
 %
 % INPUTS
 %    o parameters  a string ('posterior mode','posterior mean','posterior median','prior mode','prior mean') or a vector of values for
 %                  the (estimated) parameters of the model.
-%
+%    o M_         [structure]     Definition of the model
+%    o estim_params_ [structure]  characterizing parameters to be estimated
+%    o oo_         [structure]    Storage of results
+%    o options_    [structure]    Options
+%    o bayestopt_  [structure]    describing the priors
+%    o llik        [double]       value of the logged likelihood if it
+%                                   should not be computed
 %
 % OUTPUTS
 %    o lpkern      [double]  value of the logged posterior kernel.
@@ -34,8 +40,8 @@ function lpkern = evaluate_posterior_kernel(parameters,llik)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-[ldens,parameters] = evaluate_prior(parameters);
-if nargin==1
-    llik = evaluate_likelihood(parameters);
+[ldens,parameters] = evaluate_prior(parameters,M_,estim_params_,oo_,options_,bayestopt_);
+if nargin==6 %llik provided as an input
+    llik = evaluate_likelihood(parameters,M_,estim_params_,oo_,options_,bayestopt_);
 end
 lpkern = ldens+llik;
\ No newline at end of file
