@@ -11,7 +11,7 @@ function formdata(fname,date)
 % SPECIAL REQUIREMENT
 %   none
 
-% Copyright (C) 2007-2017 Dynare Team
+% Copyright (C) 2007-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,11 +31,11 @@ function formdata(fname,date)
 global M_ oo_
 
 fid = fopen([fname '_endo.frm'],'w');
-n=size(oo_.endo_simul,1);
-t=size(oo_.endo_simul,2);
-SN=upper(cellstr(M_.endo_names));
-for i=1:n
-    str=char(SN(i));
+n = size(oo_.endo_simul, 1);
+t = size(oo_.endo_simul, 2);
+SN = upper(M_.endo_names);
+for i = 1:n
+    str=SN{i};
     fprintf(fid,'USER: x x DATAFILE: x %s\n',str);
     fprintf(fid,'PER: 1    YEAR: %s   FRAC: 1   NOBS: %d   CLINES: 0   DLINES: ???\n',date,t);
     fprintf(fid,'%10.5f %10.5f %10.5f %10.5f\n',reshape(oo_.endo_simul(i,1:floor(t/4)*4),floor(t/4),4));
@@ -56,9 +56,9 @@ fclose(fid);
 fid = fopen([fname '_exo.frm'],'w');
 n=size(oo_.exo_simul,2);
 t=size(oo_.exo_simul,1);
-SN=upper(cellstr(M_.exo_names));
+SN=upper(M_.exo_names);
 for i=1:n
-    str=char(SN(i));
+    str = SN{i};
     fprintf(fid,'USER: x x DATAFILE: x %s\n',str);
     fprintf(fid,'PER: 1    YEAR: %s   FRAC: 1   NOBS: %d   CLINES: 0   DLINES: ???\n',date,t);
     fprintf(fid,'%10.5f %10.5f %10.5f %10.5f\n',reshape(oo_.exo_simul(1:floor(t/4)*4,i),floor(t/4),4));
