@@ -1,14 +1,16 @@
-function [ivar,vartan,options_] = get_variables_list(options_,M_)
+function [ivar, vartan, options_] = get_variables_list(options_, M_)
+
 % This function builds a vector of indices in varlist or varobs.
 %
 % INPUTS
-%   o options_   [structure]  Describes global options.
-%   o M_         [structure]  Describes the model.
+%   o options_   [structure]             Describes global options.
+%   o M_         [structure]             Describes the model.
+%
 % OUTPUTS
-%   o ivar       [integer]    nvar*1 vector of indices (nvar is the number
-%                             of variables).
-%   o vartan     [char]       array of characters (with nvar rows).
-%   o options_   [structure]  Describes global options.
+%   o ivar       [integer]               nvar*1 vector of indices (nvar is the number
+%                                        of variables).
+%   o vartan     [cell of char arrays]   array of characters (with nvar rows).
+%   o options_   [structure]             Describes global options.
 %
 % ALGORITHM
 %   None.
@@ -16,7 +18,7 @@ function [ivar,vartan,options_] = get_variables_list(options_,M_)
 % SPECIAL REQUIREMENTS
 %   None.
 
-% Copyright (C) 2007-2017 Dynare Team
+% Copyright (C) 2007-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -35,13 +37,12 @@ function [ivar,vartan,options_] = get_variables_list(options_,M_)
 
 varlist = options_.varlist;
 if isempty(varlist)
-    varlist = char(options_.varobs);
+    varlist = options_.varobs;
     options_.varlist = varlist;
 end
-nvar = rows(varlist);
+nvar = length(varlist);
 vartan = varlist;
-nvar = size(vartan,1);
 ivar = zeros(nvar,1);
 for i = 1:nvar
-    ivar(i) = strmatch(deblank(vartan(i,:)),M_.endo_names,'exact');
+    ivar(i) = strmatch(vartan{i}, M_.endo_names, 'exact');
 end
\ No newline at end of file
