@@ -14,7 +14,7 @@ function [rmse_MC, ixx] = filt_mc_(OutDir,options_gsa_,dataset_,dataset_info)
 % marco.ratto@ec.europa.eu
 
 % Copyright (C) 2012-2016 European Commission
-% Copyright (C) 2012-2017 Dynare Team
+% Copyright (C) 2012-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -38,12 +38,11 @@ vvarvecm = options_gsa_.var_rmse;
 if options_.TeX
     vvarvecm_tex = options_gsa_.var_rmse_tex;
 else
-    vvarvecm_tex = [];
+    vvarvecm_tex = {};
 end
 loadSA   = options_gsa_.load_rmse;
 pfilt    = options_gsa_.pfilt_rmse;
 alpha    = options_gsa_.alpha_rmse;
-% alpha2   = options_gsa_.alpha2_rmse;
 alpha2 = 0;
 pvalue   = options_gsa_.alpha2_rmse;
 istart   = max(2,options_gsa_.istart_rmse);
@@ -133,7 +132,6 @@ if ~loadSA
         M_ = set_all_parameters(xparam1_mean,estim_params_,M_);
         ys_mean=steady_(M_,options_,oo_);
     end
-    %   eval(options_.datafile)
     Y = transpose(dataset_.data);
     gend = dataset_.nobs;
     data_index = dataset_info.missing.aindex;
@@ -141,8 +139,6 @@ if ~loadSA
     for jx=1:gend
         data_indx(jx,data_index{jx})=true;
     end
-    %stock_gend=data_info.gend;
-    %stock_data = data_info.data;
     load([DirectoryName filesep M_.fname '_data.mat']);
     filfilt = dir([DirectoryName filesep M_.fname '_filter_step_ahead*.mat']);
     temp_smooth_file_list = dir([DirectoryName filesep M_.fname '_smooth*.mat']);
@@ -159,7 +155,6 @@ if ~loadSA
     logpo2=[];
     sto_ys=[];
     for j=1:length(filparam)
-        %load([DirectoryName filesep M_.fname '_param',int2str(j),'.mat']);
         if isempty(strmatch([M_.fname '_param_irf'],filparam(j).name))
             load([DirectoryName filesep filparam(j).name]);
             x=[x; stock];
@@ -173,11 +168,10 @@ if ~loadSA
     if options_.opt_gsa.ppost || (options_.opt_gsa.ppost==0 && options_.opt_gsa.lik_only==0)
         skipline()
         disp('Computing RMSE''s...')
-        for i=1:size(vvarvecm,1)
-            vj=deblank(vvarvecm(i,:));
-
-            jxj(i) = strmatch(vj,lgy_(dr_.order_var,:),'exact');
-            js(i) = strmatch(vj,lgy_,'exact');
+        for i = 1:length(vvarvecm)
+            vj = vvarvecm{i};
+            jxj(i) = strmatch(vj, lgy_(dr_.order_var), 'exact');
+            js(i) = strmatch(vj, lgy_, 'exact');
             yss(i,:,:)=repmat(sto_ys(:,js(i))',[gend,1]);
         end
         if exist('xparam1','var')
@@ -213,7 +207,6 @@ if ~loadSA
             r2_MC(j,:) = 1-mean((yobs(:,istart:end,j)'-y0(:,istart:end,j)').^2)./mean((yobs(:,istart:end,j)').^2);
         end
         if exist('xparam1_mean','var')
-            %eval(['rmse_pmean(i) = sqrt(mean((',vj,'(fobs-1+istart:fobs-1+nobs)-y0M(istart:end-1)).^2));'])
             [alphahat,etahat,epsilonhat,ahat,SteadyState,trend_coeff,aK] = DsgeSmoother(xparam1_mean,gend,Y,data_index,missing_value,M_,oo_,options_,bayestopt_,estim_params_);
             y0 = reshape( squeeze(aK(1,jxj,1:gend)),[gend length(jxj)]);% + kron(ys_mean(js),ones(1,gend)));
             yobs = transpose( ahat(jxj,:));% + kron(ys_mean(js),ones(1,gend)));
@@ -260,14 +253,14 @@ else
     nfilt=floor(pfilt*nruns);
 end
 % smirnov tests
-nfilt0=nfilt*ones(size(vvarvecm,1),1);
+nfilt0 = nfilt*ones(length(vvarvecm), 1);
 logpo2=logpo2(:);
 if ~options_.opt_gsa.ppost
     [dum, ipost]=sort(-logpo2);
     [dum, ilik]=sort(-likelihood);
 end
 
-%% visual scatter analysis!
+% visual scatter analysis!
 if options_.opt_gsa.ppost
     tmp_title='R2 Posterior:';
     atitle='R2 Posterior:';
@@ -291,8 +284,7 @@ options_scatter.amcf_name = asname;
 options_scatter.amcf_title = atitle;
 options_scatter.title = tmp_title;
 scatter_analysis(r2_MC, x,options_scatter, options_);
-%% end of visual scatter analysis
-
+% end of visual scatter analysis
 
 if ~options_.opt_gsa.ppost && options_.opt_gsa.lik_only
     if options_.opt_gsa.pprior
@@ -307,12 +299,12 @@ if ~options_.opt_gsa.ppost && options_.opt_gsa.lik_only
     options_mcf.alpha2 = alpha2;
     if options_.TeX
         [pnames,pnames_tex]=get_LaTeX_parameter_names(M_,options_,estim_params_,bayestopt_);
-        options_mcf.param_names = char(pnames);
-        options_mcf.param_names_tex = char(pnames_tex);
+        options_mcf.param_names = pnames;
+        options_mcf.param_names_tex = pnames_tex;
     else
         [pnames]=get_LaTeX_parameter_names(M_,options_,estim_params_,bayestopt_);
-        options_mcf.param_names = char(pnames);
-        options_mcf.param_names_tex = [];
+        options_mcf.param_names = pnames;
+        options_mcf.param_names_tex = {};
     end
     options_mcf.fname_ = fname_;
     options_mcf.OutputDirectoryName = OutDir;
@@ -322,7 +314,6 @@ if ~options_.opt_gsa.ppost && options_.opt_gsa.lik_only
     options_mcf.beha_title = 'better posterior kernel';
     options_mcf.nobeha_title = 'worse posterior kernel';
     mcf_analysis(x, ipost(1:nfilt), ipost(nfilt+1:end), options_mcf, options_);
-
     if options_.opt_gsa.pprior
         anam = 'rmse_prior_lik';
         atitle = 'RMSE prior: Log Likelihood Kernel';
@@ -351,22 +342,21 @@ else
                 r2_txt=NaN(1,size(r2_MC,2));
             end
         else
-            %nfilt0(i)=length(find(rmse_MC(:,i)<rmse_pmean(i)));
             rmse_txt=rmse_pmean;
             r2_txt=r2_pmean;
         end
     end
-    for i=1:size(vvarvecm,1)
-        [dum, ixx(:,i)]=sort(rmse_MC(:,i));
+    for i = 1:length(vvarvecm)
+        [dum, ixx(:,i)] = sort(rmse_MC(:,i));
     end
-    PP=ones(npar+nshock,size(vvarvecm,1));
-    PPV=ones(size(vvarvecm,1),size(vvarvecm,1),npar+nshock);
-    SS=zeros(npar+nshock,size(vvarvecm,1));
-    for j=1:npar+nshock
-        for i=1:size(vvarvecm,1)
-            [H,P,KSSTAT] = smirnov(x(ixx(nfilt0(i)+1:end,i),j),x(ixx(1:nfilt0(i),i),j), alpha);
-            [H1,P1,KSSTAT1] = smirnov(x(ixx(nfilt0(i)+1:end,i),j),x(ixx(1:nfilt0(i),i),j),alpha,1);
-            [H2,P2,KSSTAT2] = smirnov(x(ixx(nfilt0(i)+1:end,i),j),x(ixx(1:nfilt0(i),i),j),alpha,-1);
+    PP = ones(npar+nshock, length(vvarvecm));
+    PPV = ones(length(vvarvecm), length(vvarvecm), npar+nshock);
+    SS = zeros(npar+nshock, length(vvarvecm));
+    for j = 1:npar+nshock
+        for i = 1:length(vvarvecm)
+            [H, P, KSSTAT] = smirnov(x(ixx(nfilt0(i)+1:end,i),j),x(ixx(1:nfilt0(i),i),j), alpha);
+            [H1, P1, KSSTAT1] = smirnov(x(ixx(nfilt0(i)+1:end,i),j),x(ixx(1:nfilt0(i),i),j),alpha,1);
+            [H2, P2, KSSTAT2] = smirnov(x(ixx(nfilt0(i)+1:end,i),j),x(ixx(1:nfilt0(i),i),j),alpha,-1);
             if H1 & H2==0
                 SS(j,i)=1;
             elseif H1==0
@@ -376,17 +366,11 @@ else
             end
             PP(j,i)=P;
         end
-        for i=1:size(vvarvecm,1)
-            for l=1:size(vvarvecm,1)
+        for i = 1:length(vvarvecm)
+            for l = 1:length(vvarvecm)
                 if l~=i && PP(j,i)<alpha && PP(j,l)<alpha
                     [H,P,KSSTAT] = smirnov(x(ixx(1:nfilt0(i),i),j),x(ixx(1:nfilt0(l),l),j), alpha);
-                    %[H1,P1,KSSTAT1] = smirnov(x(ixx(1:nfilt0(i),i),j),x(:,j), alpha);
-                    %                 PP(j,i)=min(P,PP(j,i));
-                    %                 PP(j,l)=min(P,PP(j,l));
-                    %if P<P1
-                    %                     if SS(j,i)*SS(j,l)
                     PPV(i,l,j) = P;
-                    %                     end
                 elseif l==i
                     PPV(i,l,j) = PP(j,i);
                 end
@@ -395,7 +379,7 @@ else
     end
     if ~options_.nograph
         ifig=0;
-        for i=1:size(vvarvecm,1)
+        for i=1:length(vvarvecm)
             if options_.opt_gsa.ppost
                 temp_name='RMSE Posterior: Log Prior';
             else
@@ -416,8 +400,8 @@ else
             set(h,'color','k','linewidth',1)
             h=cumplot(lnprior(ixx(nfilt0(i)+1:end,i)));
             set(h,'color','red','linewidth',2)
-            title(vvarvecm(i,:),'interpreter','none')
-            if mod(i,9)==0 || i==size(vvarvecm,1)
+            title(vvarvecm{i},'interpreter','none')
+            if mod(i,9)==0 || i==length(vvarvecm)
                 if ~isoctave
                     annotation('textbox', [0.1,0,0.35,0.05],'String', 'Log-prior for BETTER R2','Color','Blue','horizontalalignment','center');
                     annotation('textbox', [0.55,0,0.35,0.05],'String', 'Log-prior for WORSE R2', 'Color','Red','horizontalalignment','center');
@@ -443,7 +427,7 @@ else
             end
         end
         ifig=0;
-        for i=1:size(vvarvecm,1)
+        for i=1:length(vvarvecm)
             if options_.opt_gsa.ppost
                 temp_name='RMSE Posterior: Log Likelihood';
             else
@@ -464,11 +448,11 @@ else
             set(h,'color','k','linewidth',1)
             h=cumplot(likelihood(ixx(nfilt0(i)+1:end,i)));
             set(h,'color','red','linewidth',2)
-            title(vvarvecm(i,:),'interpreter','none')
+            title(vvarvecm{i},'interpreter','none')
             if options_.opt_gsa.ppost==0
                 set(gca,'xlim',[min( likelihood(ixx(1:nfilt0(i),i)) ) max( likelihood(ixx(1:nfilt0(i),i)) )])
             end
-            if mod(i,9)==0 || i==size(vvarvecm,1)
+            if mod(i,9)==0 || i==length(vvarvecm)
                 if ~isoctave
                     annotation('textbox', [0.1,0,0.35,0.05],'String', 'Log-likelihood for BETTER R2','Color','Blue','horizontalalignment','center');
                     annotation('textbox', [0.55,0,0.35,0.05],'String', 'Log-likelihood for WORSE R2', 'Color','Red','horizontalalignment','center');
@@ -494,7 +478,7 @@ else
             end
         end
         ifig=0;
-        for i=1:size(vvarvecm,1)
+        for i=1:length(vvarvecm)
             if options_.opt_gsa.ppost
                 temp_name='RMSE Posterior: Log Posterior';
             else
@@ -515,11 +499,11 @@ else
             set(h,'color','k','linewidth',1)
             h=cumplot(logpo2(ixx(nfilt0(i)+1:end,i)));
             set(h,'color','red','linewidth',2)
-            title(vvarvecm(i,:),'interpreter','none')
+            title(vvarvecm{i},'interpreter','none')
             if options_.opt_gsa.ppost==0
                 set(gca,'xlim',[min( logpo2(ixx(1:nfilt0(i),i)) ) max( logpo2(ixx(1:nfilt0(i),i)) )])
             end
-            if mod(i,9)==0 || i==size(vvarvecm,1)
+            if mod(i,9)==0 || i==length(vvarvecm)
                 if ~isoctave
                     annotation('textbox', [0.1,0,0.35,0.05],'String', 'Log-posterior for BETTER R2','Color','Blue','horizontalalignment','center');
                     annotation('textbox', [0.55,0,0.35,0.05],'String', 'Log-posterior for WORSE R2', 'Color','Red','horizontalalignment','center');
@@ -545,64 +529,50 @@ else
             end
         end
     end
-
     if options_.TeX
         [pnames,pnames_tex]=get_LaTeX_parameter_names(M_,options_,estim_params_,bayestopt_);
-        param_names = char(pnames);
-        param_names_tex = char(pnames_tex);
+        param_names = pnames;
+        param_names_tex = pnames_tex;
     else
         [pnames]=get_LaTeX_parameter_names(M_,options_,estim_params_,bayestopt_);
-        param_names = char(pnames);
-        param_names_tex = [];
+        param_names = pnames;
+        param_names_tex = {};
     end
-
-
     skipline()
     title_string='RMSE over the MC sample:';
     data_mat=[min(rmse_MC)' max(rmse_MC)'];
-    headers=strvcat('Variable','min yr RMSE','max yr RMSE');
-    dyntable(options_,title_string,headers,vvarvecm,data_mat, 0, 15, 5);
+    headers={'Variable'; 'min yr RMSE'; 'max yr RMSE'};
+    dyntable(options_, title_string, headers, vvarvecm, data_mat, 0, 15, 5);
     if options_.TeX
-        headers_tex=strvcat('\text{Variable}','\text{min yr RMSE}','\text{max yr RMSE}');
-        dyn_latex_table(M_,options_,title_string,'RMSE_MC',headers_tex,vvarvecm_tex,data_mat,0,15,5);
+        headers_tex = {'\text{Variable}'; '\text{min yr RMSE}'; '\text{max yr RMSE}'};
+        dyn_latex_table(M_, options_, title_string, 'RMSE_MC', headers_tex, vvarvecm_tex, data_mat, 0, 15, 5);
     end
-
     invar = find( std(rmse_MC)./mean(rmse_MC)<=0.0001 );
     if ~isempty(invar)
         skipline(2)
         disp('RMSE is not varying significantly over the MC sample for the following variables:')
-        disp(vvarvecm(invar,:))
+        disp(vvarvecm{invar})
         disp('These variables are excluded from SA')
         disp('[Unless you treat these series as exogenous, there is something wrong in your estimation !]')
     end
     vvarvecm0=vvarvecm;
-
     ivar = find( std(rmse_MC)./mean(rmse_MC)>0.0001 );
-    vvarvecm=vvarvecm(ivar,:);
-    rmse_MC=rmse_MC(:,ivar);
-
+    vvarvecm = vvarvecm(ivar);
+    rmse_MC = rmse_MC(:,ivar);
     skipline()
-    % if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior,
     disp(['Sample filtered the ',num2str(pfilt*100),'% best RMSE''s for each observed series ...' ])
-    % else
-    %   disp(['Sample filtered the best RMSE''s smaller than RMSE at the posterior mean ...' ])
-    % end
-    % figure, boxplot(rmse_MC)
-    % set(gca,'xticklabel',vvarvecm)
-    % saveas(gcf,[fname_,'_SA_RMSE'])
-
     skipline(2)
     disp('RMSE ranges after filtering:')
     title_string='RMSE ranges after filtering:';
     if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior
-        headers=strvcat('Variable','min','max','min','max','posterior mode');
-        headers_tex=strvcat('\text{Variable}','\text{min}','\text{max}','\text{min}','\text{max}','\text{posterior mode}');
+        headers = {'Variable'; 'min'; 'max'; 'min'; 'max'; 'posterior mode'};
+        headers_tex = {'\text{Variable}'; '\text{min}'; '\text{max}'; '\text{min}'; '\text{max}'; '\text{posterior mode}'};
     else
-        headers=strvcat('Variable','min','max','min','max','posterior mean');
-        headers_tex=strvcat('\text{Variable}','\text{min}','\text{max}','\text{min}','\text{max}','\text{posterior mean}');
+        headers = {'Variable'; 'min'; 'max'; 'min'; 'max'; 'posterior mean'};
+        headers_tex = {'\text{Variable}'; '\text{min}'; '\text{max}'; '\text{min}'; '\text{max}'; '\text{posterior mean}'};
     end
-    data_mat=NaN(size(vvarvecm,1),5);
-    for j=1:size(vvarvecm,1)
+    data_mat=NaN(length(vvarvecm),5);
+    for j = 1:length(vvarvecm)
         data_mat(j,:)=[min(rmse_MC(ixx(1:nfilt0(j),j),j)) ...
                        max(rmse_MC(ixx(1:nfilt0(j),j),j))  ...
                        min(rmse_MC(ixx(nfilt0(j)+1:end,j),j)) ...
@@ -610,10 +580,10 @@ else
                        rmse_txt(j)];
     end
     %get formatting for additional header line
-    val_width=15;
-    val_precis=5;
-    label_width = max(size(deblank(char(headers(1,:),vvarvecm)),2)+2,0);
-    label_format_leftbound  = sprintf('%%-%ds',label_width);
+    val_width = 15;
+    val_precis = 5;
+    label_width = max(cellofchararraymaxlength(vertcat(headers{1}, vvarvecm))+2, 0);
+    label_format_leftbound  = sprintf('%%-%ds', label_width);
     if all(~isfinite(data_mat))
         values_length = 4;
     else
@@ -622,61 +592,55 @@ else
     if any(data_mat) < 0 %add one character for minus sign
         values_length = values_length+1;
     end
-
-    headers_length = max(size(deblank(headers(2:end,:)),2));
+    headers_length = cellofchararraymaxlength(headers(2:end));
     if ~isempty(val_width)
-        val_width = max(max(headers_length,values_length)+2,val_width);
+        val_width = max(max(headers_length,values_length)+2, val_width);
     else
-        val_width = max(headers_length,values_length)+2;
+        val_width = max(headers_length, values_length)+2;
     end
     value_format  = sprintf('%%%d.%df',val_width,val_precis);
     header_string_format  = sprintf('%%%ds',val_width);
-
     if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior
         optional_header=sprintf([label_format_leftbound,header_string_format,header_string_format,header_string_format,header_string_format],'','',['best ',num2str(pfilt*100),'% filtered'],'','remaining 90%');
     else
         optional_header=sprintf([label_format_leftbound,header_string_format,header_string_format,header_string_format,header_string_format],'','','best  filtered','','remaining');
     end
-    dyntable(options_,title_string,headers,vvarvecm,data_mat, 0, val_width, val_precis,optional_header);
+    dyntable(options_, title_string, headers, vvarvecm, data_mat, 0, val_width, val_precis,optional_header);
     if options_.TeX
         if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior
             optional_header={[' & \multicolumn{2}{c}{best ',num2str(pfilt*100),' filtered} & \multicolumn{2}{c}{remaining 90\%}\\']};
         else
             optional_header={[' & \multicolumn{2}{c}{best filtered} & \multicolumn{2}{c}{remaining}\\']};
         end
-        dyn_latex_table(M_,options_,title_string,'RMSE_ranges_after_filtering',headers_tex,vvarvecm_tex,data_mat,0,val_width,val_precis,optional_header);
+        dyn_latex_table(M_, options_, title_string, 'RMSE_ranges_after_filtering', headers_tex, vvarvecm_tex, data_mat, 0, val_width, val_precis, optional_header);
     end
-
-    %%%%% R2 table
+    % R2 table
     vvarvecm=vvarvecm0;
     skipline()
     title_string='R2 over the MC sample:';
     data_mat=[min(r2_MC)' max(r2_MC)'];
-    headers=strvcat('Variable','min yr R2','max yr R2');
-    dyntable(options_,title_string,headers,vvarvecm,data_mat, 0, 15, 5);
+    headers = {'Variable'; 'min yr R2'; 'max yr R2'};
+    dyntable(options_, title_string, headers, vvarvecm, data_mat, 0, 15, 5);
     if options_.TeX
-        headers_tex=strvcat('\text{Variable}','\text{min yr R2}','\text{max yr R2}');
-        dyn_latex_table(M_,options_,title_string,'R2_MC',headers_tex,vvarvecm_tex,data_mat,0,15,5);
+        headers_tex = {'\text{Variable}'; '\text{min yr R2}'; '\text{max yr R2}'};
+        dyn_latex_table(M_, options_, title_string, 'R2_MC', headers_tex, vvarvecm_tex, data_mat, 0, 15, 5);
     end
-
     r2_MC=r2_MC(:,ivar);
-    vvarvecm=vvarvecm(ivar,:);
-
+    vvarvecm=vvarvecm(ivar);
     skipline()
     disp(['Sample filtered the ',num2str(pfilt*100),'% best R2''s for each observed series ...' ])
-
     skipline()
     disp('R2 ranges after filtering:')
     title_string='R2 ranges after filtering:';
     if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior
-        headers=strvcat('Variable','min','max','min','max','posterior mode');
-        headers_tex=strvcat('\text{Variable}','\text{min}','\text{max}','\text{min}','\text{max}','\text{posterior mode}');
+        headers = {'Variable'; 'min'; 'max'; 'min'; 'max'; 'posterior mode'};
+        headers_tex = {'\text{Variable}'; '\text{min}'; '\text{max}'; '\text{min}'; '\text{max}'; '\text{posterior mode}'};
     else
-        headers=strvcat('Variable','min','max','min','max','posterior mean');
-        headers_tex=strvcat('\text{Variable}','\text{min}','\text{max}','\text{min}','\text{max}','\text{posterior mean}');
+        headers = {'Variable'; 'min'; 'max'; 'min'; 'max'; 'posterior mean'};
+        headers_tex = {'\text{Variable}'; '\text{min}'; '\text{max}'; '\text{min}'; '\text{max}'; '\text{posterior mean}'};
     end
-    data_mat=NaN(size(vvarvecm,1),5);
-    for j=1:size(vvarvecm,1)
+    data_mat=NaN(length(vvarvecm),5);
+    for j = 1:length(vvarvecm)
         data_mat(j,:)=[min(r2_MC(ixx(1:nfilt0(j),j),j)) ...
                        max(r2_MC(ixx(1:nfilt0(j),j),j))  ...
                        min(r2_MC(ixx(nfilt0(j)+1:end,j),j)) ...
@@ -684,10 +648,10 @@ else
                        r2_txt(j)];
     end
     %get formatting for additional header line
-    val_width=15;
-    val_precis=5;
-    label_width = max(size(deblank(char(headers(1,:),vvarvecm)),2)+2,0);
-    label_format_leftbound  = sprintf('%%-%ds',label_width);
+    val_width = 15;
+    val_precis = 5;
+    label_width = max(cellofchararraymaxlength(vertcat(headers{1}, vvarvecm))+2, 0);
+    label_format_leftbound  = sprintf('%%-%ds', label_width);
     if all(~isfinite(data_mat))
         values_length = 4;
     else
@@ -696,35 +660,32 @@ else
     if any(data_mat) < 0 %add one character for minus sign
         values_length = values_length+1;
     end
-
-    headers_length = max(size(deblank(headers(2:end,:)),2));
+    headers_length = cellofchararraymaxlength(headers(2:end));
     if ~isempty(val_width)
-        val_width = max(max(headers_length,values_length)+2,val_width);
+        val_width = max(max(headers_length, values_length)+2, val_width);
     else
-        val_width = max(headers_length,values_length)+2;
+        val_width = max(headers_length, values_length)+2;
     end
     value_format  = sprintf('%%%d.%df',val_width,val_precis);
     header_string_format  = sprintf('%%%ds',val_width);
 
     if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior
-        optional_header=sprintf([label_format_leftbound,header_string_format,header_string_format,header_string_format,header_string_format],'','',['best ',num2str(pfilt*100),'% filtered'],'','remaining 90%');
+        optional_header = sprintf([label_format_leftbound,header_string_format,header_string_format,header_string_format,header_string_format],'','',['best ',num2str(pfilt*100),'% filtered'],'','remaining 90%');
     else
-        optional_header=sprintf([label_format_leftbound,header_string_format,header_string_format,header_string_format,header_string_format],'','','best  filtered','','remaining');
+        optional_header = sprintf([label_format_leftbound,header_string_format,header_string_format,header_string_format,header_string_format],'','','best  filtered','','remaining');
     end
-    dyntable(options_,title_string,headers,vvarvecm,data_mat, 0, val_width, val_precis,optional_header);
+    dyntable(options_, title_string, headers, vvarvecm, data_mat, 0, val_width, val_precis, optional_header);
     if options_.TeX
-        if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior
-            optional_header={[' & \multicolumn{2}{c}{best ',num2str(pfilt*100),' filtered} & \multicolumn{2}{c}{remaining 90\%}\\']};
+        if ~options_.opt_gsa.ppost && options_.opt_gsa.pprior
+            optional_header = {[' & \multicolumn{2}{c}{best ',num2str(pfilt*100),' filtered} & \multicolumn{2}{c}{remaining 90\%}\\']};
         else
-            optional_header={[' & \multicolumn{2}{c}{best filtered} & \multicolumn{2}{c}{remaining}\\']};
+            optional_header = {[' & \multicolumn{2}{c}{best filtered} & \multicolumn{2}{c}{remaining}\\']};
         end
-        dyn_latex_table(M_,options_,title_string,'R2_ranges_after_filtering',headers_tex,vvarvecm_tex,data_mat,0,val_width,val_precis,optional_header);
+        dyn_latex_table(M_, options_, title_string, 'R2_ranges_after_filtering', headers_tex, vvarvecm_tex, data_mat, 0, val_width, val_precis, optional_header);
     end
-
-
-    %%%%  R2 table
-    SP=zeros(npar+nshock,size(vvarvecm,1));
-    for j=1:size(vvarvecm,1)
+    %  R2 table
+    SP = zeros(npar+nshock, length(vvarvecm));
+    for j = 1:length(vvarvecm)
         ns=find(PP(:,j)<alpha);
         SP(ns,j)=ones(size(ns));
         SS(:,j)=SS(:,j).*SP(:,j);
@@ -733,33 +694,24 @@ else
     for j=1:npar+nshock %estim_params_.np,
         nsp(j)=length(find(SP(j,:)));
     end
-    snam0=param_names(find(nsp==0),:);
-    snam1=param_names(find(nsp==1),:);
-    snam2=param_names(find(nsp>1),:);
-    snam=param_names(find(nsp>0),:);
-    % snam0=bayestopt_.name(find(nsp==0));
-    % snam1=bayestopt_.name(find(nsp==1));
-    % snam2=bayestopt_.name(find(nsp>1));
-    % snam=bayestopt_.name(find(nsp>0));
+    snam0=param_names(find(nsp==0));
+    snam1=param_names(find(nsp==1));
+    snam2=param_names(find(nsp>1));
+    snam=param_names(find(nsp>0));
     nsnam=(find(nsp>1));
-
     skipline(2)
     disp('These parameters do not affect significantly the fit of ANY observed series:')
-    disp(snam0)
+    disp(char(snam0))
     skipline()
     disp('These parameters affect ONE single observed series:')
-    disp(snam1)
+    disp(char(snam1))
     skipline()
     disp('These parameters affect MORE THAN ONE observed series: trade off exists!')
-    disp(snam2)
-
-
-    %pnam=bayestopt_.name(end-estim_params_.np+1:end);
+    disp(char(snam2))
     pnam=bayestopt_.name;
-
     % plot trade-offs
     if ~options_.nograph
-        a00=jet(size(vvarvecm,1));
+        a00=jet(length(vvarvecm));
         if options_.opt_gsa.ppost
             temp_name='RMSE Posterior Tradeoffs:';
             atitle='RMSE Posterior Map:';
@@ -783,33 +735,30 @@ else
         options_mcf.param_names_tex = param_names_tex;
         options_mcf.fname_ = fname_;
         options_mcf.OutputDirectoryName = OutDir;
-        for iy=1:size(vvarvecm,1)
-            options_mcf.amcf_name = [asname '_' deblank(vvarvecm(iy,:)) '_map' ];
-            options_mcf.amcf_title = [atitle ' ' deblank(vvarvecm(iy,:))];
-            options_mcf.beha_title = ['better fit of ' deblank(vvarvecm(iy,:))];
-            options_mcf.nobeha_title = ['worse fit of ' deblank(vvarvecm(iy,:))];
-            options_mcf.title = ['the fit of ' deblank(vvarvecm(iy,:))];
+        for iy = 1:length(vvarvecm)
+            options_mcf.amcf_name = [asname '_' vvarvecm{iy} '_map' ];
+            options_mcf.amcf_title = [atitle ' ' vvarvecm{iy}];
+            options_mcf.beha_title = ['better fit of ' vvarvecm{iy}];
+            options_mcf.nobeha_title = ['worse fit of ' vvarvecm{iy}];
+            options_mcf.title = ['the fit of ' vvarvecm{iy}];
             mcf_analysis(x, ixx(1:nfilt0(iy),iy), ixx(nfilt0(iy)+1:end,iy), options_mcf, options_);
         end
-        for iy=1:size(vvarvecm,1)
+        for iy = 1:length(vvarvecm)
             ipar = find(any(squeeze(PPV(iy,:,:))<alpha));
             for ix=1:ceil(length(ipar)/5)
-                hh = dyn_figure(options_.nodisplay,'name',[temp_name,' observed variable ',deblank(vvarvecm(iy,:))]);
+                hh = dyn_figure(options_.nodisplay,'name',[temp_name,' observed variable ', vvarvecm{iy}]);
                 for j=1+5*(ix-1):min(length(ipar),5*ix)
                     subplot(2,3,j-5*(ix-1))
-                    %h0=cumplot(x(:,nsnam(j)+nshock));
                     h0=cumplot(x(:,ipar(j)));
                     set(h0,'color',[0 0 0])
                     hold on,
                     iobs=find(squeeze(PPV(iy,:,ipar(j)))<alpha);
-                    for i=1:size(vvarvecm,1)
-                        %h0=cumplot(x(ixx(1:nfilt,np(i)),nsnam(j)+nshock));
-                        %                 h0=cumplot(x(ixx(1:nfilt0(np(i)),np(i)),nsnam(j)));
+                    for i = 1:length(vvarvecm)
                         if any(iobs==i) || i==iy
                             h0=cumplot(x(ixx(1:nfilt0(i),i),ipar(j)));
                             if ~isoctave
                                 hcmenu = uicontextmenu;
-                                uimenu(hcmenu,'Label',deblank(vvarvecm(i,:)));
+                                uimenu(hcmenu,'Label',vvarvecm{i});
                                 set(h0,'uicontextmenu',hcmenu)
                             end
                         else
@@ -818,7 +767,6 @@ else
                         set(h0,'color',a00(i,:),'linewidth',2)
                     end
                     ydum=get(gca,'ylim');
-                    %xdum=xparam1(nshock+nsnam(j));
                     if exist('xparam1')
                         xdum=xparam1(ipar(j));
                         h1=plot([xdum xdum],ydum);
@@ -827,65 +775,55 @@ else
                     xlabel('')
                     title([pnam{ipar(j)}],'interpreter','none')
                 end
-                %subplot(3,2,6)
                 if isoctave
-                    legend(char('base',vvarvecm),'location','eastoutside');
+                    legend(vertcat('base',vvarvecm),'location','eastoutside');
                 else
-                    h0=legend(char('base',vvarvecm));
+                    h0=legend(vertcat('base',vvarvecm));
                     set(h0,'fontsize',6,'position',[0.7 0.1 0.2 0.3],'interpreter','none');
                 end
-                %h0=legend({'base',vnam{np}}',0);
-                %set(findobj(get(h0,'children'),'type','text'),'interpreter','none')
                 if options_.opt_gsa.ppost
-                    dyn_saveas(hh,[ OutDir filesep fname_ '_rmse_post_' deblank(vvarvecm(iy,:)) '_' int2str(ix)],options_.nodisplay,options_.graph_format);
+                    dyn_saveas(hh,[ OutDir filesep fname_ '_rmse_post_' vvarvecm{iy} '_' int2str(ix)],options_.nodisplay,options_.graph_format);
                     if options_.TeX
-                        create_TeX_loader(options_,[ OutDir filesep fname_ '_rmse_post_' deblank(vvarvecm(iy,:)) '_' int2str(ix)],ix,[temp_name,' observed variable $',deblank(vvarvecm_tex(iy,:)) '$'],['rmse_post_' deblank(vvarvecm(iy,:))],1)
+                        create_TeX_loader(options_,[ OutDir filesep fname_ '_rmse_post_' vvarvecm{iy} '_' int2str(ix)],ix,[temp_name,' observed variable $',vvarvecm_tex{iy} '$'],['rmse_post_' vvarvecm{iy}],1)
                     end
                 else
                     if options_.opt_gsa.pprior
-                        dyn_saveas(hh,[OutDir filesep fname_ '_rmse_prior_' deblank(vvarvecm(iy,:)) '_' int2str(ix) ],options_.nodisplay,options_.graph_format);
+                        dyn_saveas(hh,[OutDir filesep fname_ '_rmse_prior_' vvarvecm{iy} '_' int2str(ix) ],options_.nodisplay,options_.graph_format);
                         if options_.TeX
-                            create_TeX_loader(options_,[OutDir filesep fname_ '_rmse_prior_' deblank(vvarvecm(iy,:)) '_' int2str(ix) ],ix,[temp_name,' observed variable $',deblank(vvarvecm_tex(iy,:)) '$'],['rmse_prior_' deblank(vvarvecm(iy,:))],1)
+                            create_TeX_loader(options_,[OutDir filesep fname_ '_rmse_prior_' vvarvecm{iy} '_' int2str(ix) ],ix,[temp_name,' observed variable $',vvarvecm_tex{iy} '$'],['rmse_prior_' vvarvecm{iy}],1)
                         end
                     else
-                        dyn_saveas(hh,[OutDir filesep fname_ '_rmse_mc_' deblank(vvarvecm(iy,:)) '_' int2str(ix)],options_.nodisplay,options_.graph_format);
+                        dyn_saveas(hh,[OutDir filesep fname_ '_rmse_mc_' vvarvecm{iy} '_' int2str(ix)],options_.nodisplay,options_.graph_format);
                         if options_.TeX
-                            create_TeX_loader(options_,[OutDir filesep fname_ '_rmse_mc_' deblank(vvarvecm(iy,:)) '_' int2str(ix)],ix,[temp_name,' observed variable $',deblank(vvarvecm_tex(iy,:)) '$'],['rmse_mc_' deblank(vvarvecm(iy,:))],1)
+                            create_TeX_loader(options_,[OutDir filesep fname_ '_rmse_mc_' vvarvecm{iy} '_' int2str(ix)],ix,[temp_name,' observed variable $',vvarvecm_tex{iy} '$'],['rmse_mc_' vvarvecm{iy}],1)
                         end
                     end
                 end
             end
         end
-
         % now I plot by individual parameters
         for ix=1:ceil(length(nsnam)/5)
             hh = dyn_figure(options_.nodisplay,'name',[temp_name,' estimated params and shocks ',int2str(ix)]);
             for j=1+5*(ix-1):min(size(snam2,1),5*ix)
                 subplot(2,3,j-5*(ix-1))
-                %h0=cumplot(x(:,nsnam(j)+nshock));
                 h0=cumplot(x(:,nsnam(j)));
                 set(h0,'color',[0 0 0])
                 hold on,
                 npx=find(SP(nsnam(j),:)==0);
-                %a0=jet(nsp(nsnam(j)));
-                %             a0=a00(np,:);
-                for i=1:size(vvarvecm,1)
-                    %h0=cumplot(x(ixx(1:nfilt,np(i)),nsnam(j)+nshock));
-                    %                 h0=cumplot(x(ixx(1:nfilt0(np(i)),np(i)),nsnam(j)));
+                for i = 1:length(vvarvecm)
                     if any(npx==i)
                         h0=cumplot(x(ixx(1:nfilt0(i),i),nsnam(j))*NaN);
                     else
                         h0=cumplot(x(ixx(1:nfilt0(i),i),nsnam(j)));
                         if ~isoctave
                             hcmenu = uicontextmenu;
-                            uimenu(hcmenu,'Label',deblank(vvarvecm(i,:)));
+                            uimenu(hcmenu,'Label', vvarvecm{i});
                             set(h0,'uicontextmenu',hcmenu)
                         end
                     end
                     set(h0,'color',a00(i,:),'linewidth',2)
                 end
                 ydum=get(gca,'ylim');
-                %xdum=xparam1(nshock+nsnam(j));
                 if exist('xparam1')
                     xdum=xparam1(nsnam(j));
                     h1=plot([xdum xdum],ydum);
@@ -896,13 +834,11 @@ else
             end
             %subplot(3,2,6)
             if isoctave
-                legend(char('base',vvarvecm),'location','eastoutside');
+                legend(vertcat('base',vvarvecm),'location','eastoutside');
             else
-                h0=legend(char('base',vvarvecm));
+                h0=legend(vertcat('base',vvarvecm));
                 set(h0,'fontsize',6,'position',[0.7 0.1 0.2 0.3],'interpreter','none');
             end
-            %h0=legend({'base',vnam{np}}',0);
-            %set(findobj(get(h0,'children'),'type','text'),'interpreter','none')
             if options_.opt_gsa.ppost
                 dyn_saveas(hh,[ OutDir filesep fname_ '_rmse_post_params_' int2str(ix)],options_.nodisplay,options_.graph_format);
                 if options_.TeX
@@ -923,66 +859,6 @@ else
             end
         end
     end
-
-    %     for j=1:size(SP,2),
-    %         nsx(j)=length(find(SP(:,j)));
-    %     end
-
-    %     skipline(2)
-    %     disp('Sensitivity table (significance and direction):')
-    %     vav=char(zeros(1, size(param_names,2)+3 ));
-    %     ibl = 12-size(vvarvecm,2);
-    %     for j=1:size(vvarvecm,1),
-    %         vav = [vav, char(zeros(1,ibl)),vvarvecm(j,:)];
-    %     end
-    %     disp(vav)
-    %     for j=1:npar+nshock, %estim_params_.np,
-    %         %disp([param_names(j,:), sprintf('%8.5g',SP(j,:))])
-    %         disp([param_names(j,:),'   ', sprintf('%12.3g',PP(j,:))])
-    %         disp([char(zeros(1, size(param_names,2)+3 )),sprintf('    (%6g)',SS(j,:))])
-    %     end
-
-
-    %     skipline()
-    %     disp('Starting bivariate analysis:')
-    %
-    %     for i=1:size(vvarvecm,1)
-    %         if options_.opt_gsa.ppost
-    %             fnam = ['rmse_post_',deblank(vvarvecm(i,:))];
-    %         else
-    %             if options_.opt_gsa.pprior
-    %                 fnam = ['rmse_prior_',deblank(vvarvecm(i,:))];
-    %             else
-    %                 fnam = ['rmse_mc_',deblank(vvarvecm(i,:))];
-    %             end
-    %         end
-    %         stab_map_2(x(ixx(1:nfilt0(i),i),:),alpha2,pvalue,fnam, OutDir,[],[temp_name ' observed variable ' deblank(vvarvecm(i,:))]);
-    %
-    %         %     [pc,latent,explained] = pcacov(c0);
-    %         %     %figure, bar([explained cumsum(explained)])
-    %         %     ifig=0;
-    %         %     j2=0;
-    %         %     for j=1:npar+nshock,
-    %         %         i2=find(abs(pc(:,j))>alphaPC);
-    %         %         if ~isempty(i2),
-    %         %             j2=j2+1;
-    %         %             if mod(j2,12)==1,
-    %         %                 ifig=ifig+1;
-    %         %                 figure('name',['PCA of the filtered sample ',deblank(vvarvecm(i,:)),' ',num2str(ifig)]),
-    %         %             end
-    %         %             subplot(3,4,j2-(ifig-1)*12)
-    %         %             bar(pc(i2,j)),
-    %         %             set(gca,'xticklabel',bayestopt_.name(i2)),
-    %         %             set(gca,'xtick',[1:length(i2)])
-    %         %             title(['PC ',num2str(j),'. Explained ',num2str(explained(j)),'%'])
-    %         %         end
-    %         %         if (mod(j2,12)==0 | j==(npar+nshock)) & j2,
-    %         %             saveas(gcf,[fname_,'_SA_PCA_',deblank(vvarvecm(i,:)),'_',int2str(ifig)])
-    %         %         end
-    %         %     end
-    %         %     close all
-    %     end
-
 end
 
 function []=create_TeX_loader(options_,figpath,label_number,caption,label_name,scale_factor)
