@@ -35,7 +35,7 @@ function x0 = stab_map_(OutputDirectoryName,opt_gsa)
 % marco.ratto@ec.europa.eu
 
 % Copyright (C) 2012-2016 European Commission
-% Copyright (C) 2012-2017 Dynare Team
+% Copyright (C) 2012-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -92,7 +92,7 @@ p2 = bayestopt_.p2(nshock+1:end);
 p3 = bayestopt_.p3(nshock+1:end);
 p4 = bayestopt_.p4(nshock+1:end);
 
-[junk1,junk2,junk3,lb,ub,junk4] = set_prior(estim_params_,M_,options_); %Prepare bounds
+[~,~,~,lb,ub,~] = set_prior(estim_params_,M_,options_); %Prepare bounds
 if ~isempty(bayestopt_) && any(bayestopt_.pshape > 0)
     % Set prior bounds
     bounds = prior_bounds(bayestopt_, options_.prior_trunc);
@@ -130,9 +130,9 @@ for jj=1:np
     end
 end
 if options_.TeX
-    options_mcf.param_names_tex=char(name_tex);
+    options_mcf.param_names_tex = name_tex;
 end
-options_mcf.param_names = char(name);
+options_mcf.param_names = name;
 
 options_mcf.fname_ = fname_;
 options_mcf.OutputDirectoryName = OutputDirectoryName;
@@ -495,7 +495,7 @@ else
         options_.nomoments=1;
         options_.irf=0;
         options_.noprint=1;
-        stoch_simul([]);
+        [~, oo_, options_] = stoch_simul(M_, options_, oo_, []);
         %T=zeros(size(dr_.ghx,1),size(dr_.ghx,2)+size(dr_.ghu,2),length(istable));
         ntrans=length(istable);
         yys=NaN(length(ys_),ntrans);
@@ -575,7 +575,7 @@ if length(iunstable)>0 || length(iwrong)>0
             disp(['    For ',num2str(length(find(infox==6))/Nsam*100,'%4.1f'),'% The jacobian evaluated at the deterministic steady state is complex.'])
         end
         if any(infox==19)
-            disp(['    For ',num2str(length(find(infox==19))/Nsam*100,'%4.1f'),'% The steadystate routine thrown an exception (inconsistent deep parameters).'])
+            disp(['    For ',num2str(length(find(infox==19))/Nsam*100,'%4.1f'),'% The steadystate routine has thrown an exception (inconsistent deep parameters).'])
         end
         if any(infox==20)
             disp(['    For ',num2str(length(find(infox==20))/Nsam*100,'%4.1f'),'% Cannot find the steady state.'])
@@ -663,9 +663,9 @@ if length(iunstable)>0 || length(iwrong)>0
                 end
             end
             if options_.TeX
-                options_mcf.param_names_tex = char(name_tex);
+                options_mcf.param_names_tex = name_tex;
             end
-            options_mcf.param_names = char(name);
+            options_mcf.param_names = name;
             options_mcf.amcf_name = acalibname;
             options_mcf.amcf_title = acalibtitle;
             options_mcf.beha_title = 'prior IRF/moment calibration';
