@@ -20,7 +20,7 @@ function DynareResults = initial_estimation_checks(objective_function,xparam1,Dy
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2003-2017 Dynare Team
+% Copyright (C) 2003-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -41,15 +41,25 @@ function DynareResults = initial_estimation_checks(objective_function,xparam1,Dy
 %singularity check
 maximum_number_non_missing_observations=max(sum(~isnan(DynareDataset.data),2));
 
-if DynareOptions.order>1 && any(any(isnan(DynareDataset.data)))
-    error('initial_estimation_checks:: particle filtering does not support missing observations')
+if DynareOptions.order>1 
+    if any(any(isnan(DynareDataset.data)))
+        error('initial_estimation_checks:: particle filtering does not support missing observations')
+    end
+    if DynareOptions.prefilter==1
+        error('initial_estimation_checks:: particle filtering does not support the prefilter option')
+    end
+    if BayesInfo.with_trend
+        error('initial_estimation_checks:: particle filtering does not support trends')
+    end
 end
 
-if maximum_number_non_missing_observations>Model.exo_nbr+EstimatedParameters.nvn
+non_zero_ME=length(EstimatedParameters.H_entries_to_check_for_positive_definiteness);
+
+if maximum_number_non_missing_observations>Model.exo_nbr+non_zero_ME
     error(['initial_estimation_checks:: Estimation can''t take place because there are less declared shocks than observed variables!'])
 end
 
-if maximum_number_non_missing_observations>length(find(diag(Model.Sigma_e)))+EstimatedParameters.nvn
+if maximum_number_non_missing_observations>length(find(diag(Model.Sigma_e)))+non_zero_ME
     error(['initial_estimation_checks:: Estimation can''t take place because too many shocks have been calibrated with a zero variance!'])
 end
 
@@ -66,14 +76,14 @@ if isfield(EstimatedParameters,'param_vals') && ~isempty(EstimatedParameters.par
     %check whether steady state file changes estimated parameters
     Model_par_varied=Model; %store Model structure
     Model_par_varied.params(EstimatedParameters.param_vals(:,1))=Model_par_varied.params(EstimatedParameters.param_vals(:,1))*1.01; %vary parameters
-    [junk, new_steady_params_2] = evaluate_steady_state(DynareResults.steady_state,Model_par_varied,DynareOptions,DynareResults,DynareOptions.diffuse_filter==0);
+    [~, new_steady_params_2] = evaluate_steady_state(DynareResults.steady_state,Model_par_varied,DynareOptions,DynareResults,DynareOptions.diffuse_filter==0);
 
     changed_par_indices=find((old_steady_params(EstimatedParameters.param_vals(:,1))-new_steady_params(EstimatedParameters.param_vals(:,1))) ...
                              | (Model_par_varied.params(EstimatedParameters.param_vals(:,1))-new_steady_params_2(EstimatedParameters.param_vals(:,1))));
 
     if ~isempty(changed_par_indices)
         fprintf('\nThe steady state file internally changed the values of the following estimated parameters:\n')
-        disp(Model.param_names(EstimatedParameters.param_vals(changed_par_indices,1),:));
+        disp(char(Model.param_names(EstimatedParameters.param_vals(changed_par_indices,1))))
         fprintf('This will override the parameter values drawn from the proposal density and may lead to wrong results.\n')
         fprintf('Check whether this is really intended.\n')
         warning('The steady state file internally changes the values of the estimated parameters.')
@@ -105,7 +115,7 @@ end
 % display warning if some parameters are still NaN
 test_for_deep_parameters_calibration(Model);
 
-[lnprior, junk1,junk2,info]= priordens(xparam1,BayesInfo.pshape,BayesInfo.p6,BayesInfo.p7,BayesInfo.p3,BayesInfo.p4);
+[lnprior,~,~,info]= priordens(xparam1,BayesInfo.pshape,BayesInfo.p6,BayesInfo.p7,BayesInfo.p3,BayesInfo.p4);
 if any(info)
     fprintf('The prior density evaluated at the initial values is Inf for the following parameters: %s\n',BayesInfo.name{info,1})
     error('The initial value of the prior is -Inf')
