@@ -1,6 +1,6 @@
 function [Da,DP,DLIK,D2a,D2P,Hesst] = computeDLIK(k,tmp,Z,Zflag,v,T,K,P,iF,Da,DYss,DT,DOm,DP,DH,notsteady,D2a,D2Yss,D2T,D2Om,D2P)
 
-% Copyright (C) 2012 Dynare Team
+% Copyright (C) 2012-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -22,22 +22,22 @@ function [Da,DP,DLIK,D2a,D2P,Hesst] = computeDLIK(k,tmp,Z,Zflag,v,T,K,P,iF,Da,DY
 persistent DK DF D2K D2F
 
 if notsteady
-if Zflag
-    [DK,DF,DP1] = computeDKalmanZ(T,DT,DOm,P,DP,DH,Z,iF,K);
-    if nargout>4,
-        [D2K,D2F,D2P] = computeD2KalmanZ(T,DT,D2T,D2Om,P,DP,D2P,DH,Z,iF,K,DK);
+    if Zflag
+        [DK,DF,DP1] = computeDKalmanZ(T,DT,DOm,P,DP,DH,Z,iF,K);
+        if nargout>4
+            [D2K,D2F,D2P] = computeD2KalmanZ(T,DT,D2T,D2Om,P,DP,D2P,DH,Z,iF,K,DK);
+        end
+    else
+        [DK,DF,DP1] = computeDKalman(T,DT,DOm,P,DP,DH,Z,iF,K);
+        if nargout>4
+            [D2K,D2F,D2P] = computeD2Kalman(T,DT,D2T,D2Om,P,DP,D2P,DH,Z,iF,K,DK);
+        end
     end
-else
-    [DK,DF,DP1] = computeDKalman(T,DT,DOm,P,DP,DH,Z,iF,K);
-    if nargout>4,
-        [D2K,D2F,D2P] = computeD2Kalman(T,DT,D2T,D2Om,P,DP,D2P,DH,Z,iF,K,DK);
-    end
-end
-DP=DP1;
-clear DP1,
+    DP=DP1;
+    clear DP1
 else
     DP=DP;
-    if nargout>4,
+    if nargout>4
         D2P=D2P;
     end
 end
@@ -47,20 +47,20 @@ Dv=zeros(length(v),k);
 for ii = 1:k
     if Zflag
         Dv(:,ii)   = -Z*Da(:,ii) - Z*DYss(:,ii);
-%         if nargout>4,
-%             for jj = 1:ii
-%                 D2v(:,jj,ii)  = -Z*D2Yss(:,jj,ii)  - Z*D2a(:,jj,ii);
-%                 D2v(:,ii,jj) = D2v(:,jj,ii);
-%             end
-%         end
+        %         if nargout>4,
+        %             for jj = 1:ii
+        %                 D2v(:,jj,ii)  = -Z*D2Yss(:,jj,ii)  - Z*D2a(:,jj,ii);
+        %                 D2v(:,ii,jj) = D2v(:,jj,ii);
+        %             end
+        %         end
     else
         Dv(:,ii)   = -Da(Z,ii) - DYss(Z,ii);
-%         if nargout>4,
-%             for jj = 1:ii
-%                 D2v(:,jj,ii)  = -D2Yss(Z,jj,ii)  - D2a(Z,jj,ii);
-%                 D2v(:,ii,jj) = D2v(:,jj,ii);
-%             end
-%         end
+        %         if nargout>4,
+        %             for jj = 1:ii
+        %                 D2v(:,jj,ii)  = -D2Yss(Z,jj,ii)  - D2a(Z,jj,ii);
+        %                 D2v(:,ii,jj) = D2v(:,jj,ii);
+        %             end
+        %         end
     end
 end
 
@@ -71,8 +71,8 @@ for ii = 1:k
     %  dai = da(:,:,ii);
     dKi  = DK(:,:,ii);
     dtmp(:,ii) = Da(:,ii)+dKi*v+K*Dv(:,ii);
-    
-    if nargout>4,
+
+    if nargout>4
         diFi = -iF*DF(:,:,ii)*iF;
         for jj = 1:ii
             jcount=jcount+1;
@@ -82,9 +82,9 @@ for ii = 1:k
             d2Kij  = D2K(:,:,jj,ii);
             d2Fij  = D2F(:,:,jj,ii);
             d2iFij = -diFi*dFj*iF -iF*d2Fij*iF -iF*dFj*diFi;
-%             dtmpj = Da(:,jj)+dKj*v+K*Dv(:,jj);
-            
-%             d2vij  = D2v(:,ii,jj);
+            %             dtmpj = Da(:,jj)+dKj*v+K*Dv(:,jj);
+
+            %             d2vij  = D2v(:,ii,jj);
             if Zflag
                 d2vij  = -Z*D2Yss(:,jj,ii)  - Z*D2a(:,jj,ii);
             else
@@ -93,36 +93,36 @@ for ii = 1:k
             d2tmpij = D2a(:,jj,ii) + d2Kij*v + dKj*Dv(:,ii) + dKi*Dv(:,jj) + K*d2vij;
             D2a(:,jj,ii) = reshape(D2T(:,jcount),size(T))*tmp + DT(:,:,jj)*dtmp(:,ii) + DT(:,:,ii)*dtmp(:,jj) + T*d2tmpij;
             D2a(:,ii,jj) = D2a(:,jj,ii);
-            
-            if nargout==6,
+
+            if nargout==6
                 Hesst(ii,jj) = getHesst_ij(v,Dv(:,ii),Dv(:,jj),d2vij,iF,diFi,diFj,d2iFij,dFj,d2Fij);
             end
         end
     end
-        
+
     Da(:,ii)   = DT(:,:,ii)*tmp + T*dtmp(:,ii);
     DLIK(ii,1)  = trace( iF*DF(:,:,ii) ) + 2*Dv(:,ii)'*iF*v - v'*(iF*DF(:,:,ii)*iF)*v;
 end
 
-if nargout==4,
+if nargout==4
     %         Hesst(ii,jj) = getHesst_ij(v,Dv(:,ii),Dv(:,jj),0,iF,diFi,diFj,0,dFj,0);
     vecDPmf = reshape(DF,[],k);
     D2a = 2*Dv'*iF*Dv + (vecDPmf' * kron(iF,iF) * vecDPmf);
-%     for ii = 1:k
-%         
-%         diFi = -iF*DF(:,:,ii)*iF;
-%         for jj = 1:ii
-%             dFj    = DF(:,:,jj);
-%             diFj   = -iF*DF(:,:,jj)*iF;
-%             
-%             Hesst(ii,jj) = getHesst_ij(v*0,Dv(:,ii),Dv(:,jj),v*0,iF,diFi,diFj,0,-dFj,0);
-%         end
-%     end
+    %     for ii = 1:k
+    %
+    %         diFi = -iF*DF(:,:,ii)*iF;
+    %         for jj = 1:ii
+    %             dFj    = DF(:,:,jj);
+    %             diFj   = -iF*DF(:,:,jj)*iF;
+    %
+    %             Hesst(ii,jj) = getHesst_ij(v*0,Dv(:,ii),Dv(:,jj),v*0,iF,diFi,diFj,0,-dFj,0);
+    %         end
+    %     end
 end
 
 % end of computeDLIK
 
-function Hesst_ij = getHesst_ij(e,dei,dej,d2eij,iS,diSi,diSj,d2iSij,dSj,d2Sij);
+function Hesst_ij = getHesst_ij(e,dei,dej,d2eij,iS,diSi,diSj,d2iSij,dSj,d2Sij)
 % computes (i,j) term in the Hessian
 
 Hesst_ij = trace(diSi*dSj + iS*d2Sij) + e'*d2iSij*e + 2*(dei'*diSj*e + dei'*iS*dej + e'*diSi*dej + e'*iS*d2eij);
@@ -165,12 +165,12 @@ end
 
 % end of computeDKalmanZ
 
-function [d2K,d2S,d2P1] = computeD2Kalman(A,dA,d2A,d2Om,P0,dP0,d2P1,DH,Z,iF,K0,dK0);
+function [d2K,d2S,d2P1] = computeD2Kalman(A,dA,d2A,d2Om,P0,dP0,d2P1,DH,Z,iF,K0,dK0)
 % computes the second derivatives of the Kalman matrices
 % note: A=T in main func.
-        
-            k      = size(dA,3);
-            tmp    = P0-K0*P0(Z,:);
+
+k      = size(dA,3);
+tmp    = P0-K0*P0(Z,:);
 [ns,no] = size(K0);
 
 % CPC = C*P0*C'; CPC = .5*(CPC+CPC');iF = inv(CPC);
@@ -186,14 +186,14 @@ jcount=0;
 for ii = 1:k
     dAi = dA(:,:,ii);
     dFi = dP0(Z,Z,ii);
-%     d2Omi = d2Om(:,:,ii);
+    %     d2Omi = d2Om(:,:,ii);
     diFi = -iF*dFi*iF;
     dKi = dK0(:,:,ii);
-    for jj = 1:ii,
+    for jj = 1:ii
         jcount=jcount+1;
         dAj = dA(:,:,jj);
         dFj = dP0(Z,Z,jj);
-%         d2Omj = d2Om(:,:,jj);
+        %         d2Omj = d2Om(:,:,jj);
         dFj = dP0(Z,Z,jj);
         diFj = -iF*dFj*iF;
         dKj = dK0(:,:,jj);
@@ -201,44 +201,44 @@ for ii = 1:k
         d2Aij = reshape(d2A(:,jcount),[ns ns]);
         d2Pij = dyn_unvech(d2P1(:,jcount));
         d2Omij = dyn_unvech(d2Om(:,jcount));
-       
-    % second order
-    
-    d2Fij = d2Pij(Z,Z) ;
-    
-%     d2APC = d2Aij*P0*C' + A*d2Pij*C' + A*P0*d2Cij' + dAi*dPj*C' + dAj*dPi*C' + A*dPj*dCi' + A*dPi*dCj' + dAi*P0*dCj' + dAj*P0*dCi';
-    d2APC = d2Pij(:,Z);
-    
-    d2iF = -diFi*dFj*iF -iF*d2Fij*iF -iF*dFj*diFi;
-    
-    d2Kij= d2Pij(:,Z)*iF + P0(:,Z)*d2iF + dP0(:,Z,jj)*diFi + dP0(:,Z,ii)*diFj;
-        
-    d2KCP = d2Kij*P0(Z,:) + K0*d2Pij(Z,:) + dKi*dP0(Z,:,jj) + dKj*dP0(Z,:,ii) ;
-    
-    dtmpi        = dP0(:,:,ii) - dK0(:,:,ii)*P0(Z,:) - K0*dP0(Z,:,ii);
-    dtmpj        = dP0(:,:,jj) - dK0(:,:,jj)*P0(Z,:) - K0*dP0(Z,:,jj);
-    d2tmp = d2Pij - d2KCP;
 
-    d2AtmpA = d2Aij*tmp*A' + A*d2tmp*A' + A*tmp*d2Aij' + dAi*dtmpj*A' + dAj*dtmpi*A' + A*dtmpj*dAi' + A*dtmpi*dAj' + dAi*tmp*dAj' + dAj*tmp*dAi';
+        % second order
 
-    d2K(:,:,ii,jj)  = d2Kij; %#ok<NASGU>
-    d2P1(:,jcount) = dyn_vech(d2AtmpA  + d2Omij);  %#ok<*NASGU>
-    d2S(:,:,ii,jj)  = d2Fij;
-    d2K(:,:,jj,ii)  = d2Kij; %#ok<NASGU>
-%     d2P1(:,:,jj,ii) = d2AtmpA  + d2Omij;  %#ok<*NASGU>
-    d2S(:,:,jj,ii)  = d2Fij;
-%     d2iS(:,:,ii,jj) = d2iF;
+        d2Fij = d2Pij(Z,Z) ;
+
+        %     d2APC = d2Aij*P0*C' + A*d2Pij*C' + A*P0*d2Cij' + dAi*dPj*C' + dAj*dPi*C' + A*dPj*dCi' + A*dPi*dCj' + dAi*P0*dCj' + dAj*P0*dCi';
+        d2APC = d2Pij(:,Z);
+
+        d2iF = -diFi*dFj*iF -iF*d2Fij*iF -iF*dFj*diFi;
+
+        d2Kij= d2Pij(:,Z)*iF + P0(:,Z)*d2iF + dP0(:,Z,jj)*diFi + dP0(:,Z,ii)*diFj;
+
+        d2KCP = d2Kij*P0(Z,:) + K0*d2Pij(Z,:) + dKi*dP0(Z,:,jj) + dKj*dP0(Z,:,ii) ;
+
+        dtmpi        = dP0(:,:,ii) - dK0(:,:,ii)*P0(Z,:) - K0*dP0(Z,:,ii);
+        dtmpj        = dP0(:,:,jj) - dK0(:,:,jj)*P0(Z,:) - K0*dP0(Z,:,jj);
+        d2tmp = d2Pij - d2KCP;
+
+        d2AtmpA = d2Aij*tmp*A' + A*d2tmp*A' + A*tmp*d2Aij' + dAi*dtmpj*A' + dAj*dtmpi*A' + A*dtmpj*dAi' + A*dtmpi*dAj' + dAi*tmp*dAj' + dAj*tmp*dAi';
+
+        d2K(:,:,ii,jj)  = d2Kij; %#ok<NASGU>
+        d2P1(:,jcount) = dyn_vech(d2AtmpA  + d2Omij);  %#ok<*NASGU>
+        d2S(:,:,ii,jj)  = d2Fij;
+        d2K(:,:,jj,ii)  = d2Kij; %#ok<NASGU>
+                                 %     d2P1(:,:,jj,ii) = d2AtmpA  + d2Omij;  %#ok<*NASGU>
+        d2S(:,:,jj,ii)  = d2Fij;
+        %     d2iS(:,:,ii,jj) = d2iF;
     end
 end
 
 % end of computeD2Kalman
 
-function [d2K,d2S,d2P1] = computeD2KalmanZ(A,dA,d2A,d2Om,P0,dP0,d2P1,DH,Z,iF,K0,dK0);
+function [d2K,d2S,d2P1] = computeD2KalmanZ(A,dA,d2A,d2Om,P0,dP0,d2P1,DH,Z,iF,K0,dK0)
 % computes the second derivatives of the Kalman matrices
 % note: A=T in main func.
-        
-            k      = size(dA,3);
-            tmp    = P0-K0*Z*P0(:,:);
+
+k      = size(dA,3);
+tmp    = P0-K0*Z*P0(:,:);
 [ns,no] = size(K0);
 
 % CPC = C*P0*C'; CPC = .5*(CPC+CPC');iF = inv(CPC);
@@ -251,17 +251,17 @@ d2S  = zeros(no,no,k,k);
 % d2P1 = zeros(ns,ns,k,k);
 
 jcount=0;
-for ii = 1:k,
+for ii = 1:k
     dAi = dA(:,:,ii);
     dFi = Z*dP0(:,:,ii)*Z;
-%     d2Omi = d2Om(:,:,ii);
+    %     d2Omi = d2Om(:,:,ii);
     diFi = -iF*dFi*iF;
     dKi = dK0(:,:,ii);
-    for jj = 1:ii,
+    for jj = 1:ii
         jcount=jcount+1;
         dAj = dA(:,:,jj);
         dFj = Z*dP0(:,:,jj)*Z;
-%         d2Omj = d2Om(:,:,jj);
+        %         d2Omj = d2Om(:,:,jj);
         dFj = Z*dP0(:,:,jj)*Z;
         diFj = -iF*dFj*iF;
         dKj = dK0(:,:,jj);
@@ -269,36 +269,34 @@ for ii = 1:k,
         d2Aij = reshape(d2A(:,jcount),[ns ns]);
         d2Pij = dyn_unvech(d2P1(:,jcount));
         d2Omij = dyn_unvech(d2Om(:,jcount));
-       
-    % second order
-    
-    d2Fij = Z*d2Pij(:,:)*Z ;
-    
-%     d2APC = d2Aij*P0*C' + A*d2Pij*C' + A*P0*d2Cij' + dAi*dPj*C' + dAj*dPi*C' + A*dPj*dCi' + A*dPi*dCj' + dAi*P0*dCj' + dAj*P0*dCi';
-    d2APC = d2Pij(:,:)*Z;
-    
-    d2iF = -diFi*dFj*iF -iF*d2Fij*iF -iF*dFj*diFi;
-    
-    d2Kij= d2Pij(:,:)*Z*iF + P0(:,:)*Z*d2iF + dP0(:,:,jj)*Z*diFi + dP0(:,:,ii)*Z*diFj;
-        
-    d2KCP = d2Kij*Z*P0(:,:) + K0*Z*d2Pij(:,:) + dKi*Z*dP0(:,:,jj) + dKj*Z*dP0(:,:,ii) ;
-    
-    dtmpi        = dP0(:,:,ii) - dK0(:,:,ii)*Z*P0(:,:) - K0*Z*dP0(:,:,ii);
-    dtmpj        = dP0(:,:,jj) - dK0(:,:,jj)*Z*P0(:,:) - K0*Z*dP0(:,:,jj);
-    d2tmp = d2Pij - d2KCP;
 
-    d2AtmpA = d2Aij*tmp*A' + A*d2tmp*A' + A*tmp*d2Aij' + dAi*dtmpj*A' + dAj*dtmpi*A' + A*dtmpj*dAi' + A*dtmpi*dAj' + dAi*tmp*dAj' + dAj*tmp*dAi';
+        % second order
 
-    d2K(:,:,ii,jj)  = d2Kij; %#ok<NASGU>
-    d2P1(:,jcount) = dyn_vech(d2AtmpA  + d2Omij);  %#ok<*NASGU>
-    d2S(:,:,ii,jj)  = d2Fij;
-%     d2iS(:,:,ii,jj) = d2iF;
-    d2K(:,:,jj,ii)  = d2Kij; %#ok<NASGU>
-%     d2P1(:,:,jj,ii) = d2AtmpA  + d2Omij;  %#ok<*NASGU>
-    d2S(:,:,jj,ii)  = d2Fij;
+        d2Fij = Z*d2Pij(:,:)*Z ;
+
+        %     d2APC = d2Aij*P0*C' + A*d2Pij*C' + A*P0*d2Cij' + dAi*dPj*C' + dAj*dPi*C' + A*dPj*dCi' + A*dPi*dCj' + dAi*P0*dCj' + dAj*P0*dCi';
+        d2APC = d2Pij(:,:)*Z;
+
+        d2iF = -diFi*dFj*iF -iF*d2Fij*iF -iF*dFj*diFi;
+
+        d2Kij= d2Pij(:,:)*Z*iF + P0(:,:)*Z*d2iF + dP0(:,:,jj)*Z*diFi + dP0(:,:,ii)*Z*diFj;
+
+        d2KCP = d2Kij*Z*P0(:,:) + K0*Z*d2Pij(:,:) + dKi*Z*dP0(:,:,jj) + dKj*Z*dP0(:,:,ii) ;
+
+        dtmpi        = dP0(:,:,ii) - dK0(:,:,ii)*Z*P0(:,:) - K0*Z*dP0(:,:,ii);
+        dtmpj        = dP0(:,:,jj) - dK0(:,:,jj)*Z*P0(:,:) - K0*Z*dP0(:,:,jj);
+        d2tmp = d2Pij - d2KCP;
+
+        d2AtmpA = d2Aij*tmp*A' + A*d2tmp*A' + A*tmp*d2Aij' + dAi*dtmpj*A' + dAj*dtmpi*A' + A*dtmpj*dAi' + A*dtmpi*dAj' + dAi*tmp*dAj' + dAj*tmp*dAi';
+
+        d2K(:,:,ii,jj)  = d2Kij; %#ok<NASGU>
+        d2P1(:,jcount) = dyn_vech(d2AtmpA  + d2Omij);  %#ok<*NASGU>
+        d2S(:,:,ii,jj)  = d2Fij;
+        %     d2iS(:,:,ii,jj) = d2iF;
+        d2K(:,:,jj,ii)  = d2Kij; %#ok<NASGU>
+                                 %     d2P1(:,:,jj,ii) = d2AtmpA  + d2Omij;  %#ok<*NASGU>
+        d2S(:,:,jj,ii)  = d2Fij;
     end
 end
 
 % end of computeD2KalmanZ
-
-
