@@ -12,7 +12,7 @@ function [lb,ub,eq_index] = get_complementarity_conditions(M,ramsey_policy)
 %                                from complementarity setup used in
 %                                perfect_foresight_mcp_problem.m
 
-% Copyright (C) 2014-2017 Dynare Team
+% Copyright (C) 2014-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -58,7 +58,7 @@ for i=1:size(etags,1)
         str = etags{i,3};
         kop = strfind(etags{i,3},'<');
         if ~isempty(kop)
-            k = find(strcmp(strtrim(str(1:kop-1)),cellstr(M.endo_names))); %get variable index with restriction
+            k = find(strcmp(strtrim(str(1:kop-1)), M.endo_names)); %get variable index with restriction
             if isempty(k)
                 error(sprintf(['Complementarity condition %s: variable %s is ' ...
                                'not recognized'],etags{i,3},strtrim(str(1:kop-1))))
@@ -69,7 +69,7 @@ for i=1:size(etags,1)
         else
             kop = strfind(etags{i,3},'>');
             if ~isempty(kop)
-                k = find(strcmp(strtrim(str(1:kop-1)),cellstr(M.endo_names))); %get variable index with restriction
+                k = find(strcmp(strtrim(str(1:kop-1)), M.endo_names)); %get variable index with restriction
                 if isempty(k)
                     error(sprintf(['Complementarity condition %s: variable %s is ' ...
                                    'not recognized'],etags{i,3},strtrim(str(1:kop-1))))
