@@ -18,7 +18,7 @@ function o2WysrOISH  = load_m_file_data_legacy(datafile, U7ORsJ0vy3) % --*-- Uni
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
 cXDHdrXnqo5KwwVpTRuc6OprAW = datafile(1:end-2);
-[pathtocXDHdrXnqo5KwwVpTRuc6OprAW,cXDHdrXnqo5KwwVpTRuc6OprAW,junk] = fileparts(cXDHdrXnqo5KwwVpTRuc6OprAW);
+[pathtocXDHdrXnqo5KwwVpTRuc6OprAW,cXDHdrXnqo5KwwVpTRuc6OprAW,~] = fileparts(cXDHdrXnqo5KwwVpTRuc6OprAW);
 
 if ~isempty(pathtocXDHdrXnqo5KwwVpTRuc6OprAW)
     % We need to change directory, first we keep the current directory in memory...
@@ -38,11 +38,11 @@ if ~isempty(pathtocXDHdrXnqo5KwwVpTRuc6OprAW)
 end
 
 % Clear all the variables except the ones defined in the script.
-clear('pathtocXDHdrXnqo5KwwVpTRuc6OprAW', 'cXDHdrXnqo5KwwVpTRuc6OprAW', 'junk');
+clear('pathtocXDHdrXnqo5KwwVpTRuc6OprAW', 'cXDHdrXnqo5KwwVpTRuc6OprAW');
 
 % Get the list of variables in the script.
 mj6F4eU1BN = whos();
-Z3s1ZFBffw = {mj6F4eU1BN(:).name};
+Z3s1ZFBffw = {mj6F4eU1BN(:).name}';
 
 % Check that the variables in varobs are available.
 if ~isequal(sort(intersect(Z3s1ZFBffw, U7ORsJ0vy3)), sort(U7ORsJ0vy3))
@@ -95,15 +95,16 @@ fwriten(fid, '  f(i) = log(rand());')
 fwriten(fid, 'end');
 fclose(fid);
 % Define a set of variables to be loaded.
-listofvariablestobeloaded = {'b', 'a'};
+listofvariablestobeloaded = {'b'; 'a'};
 % Test if we can load the data.
+exist('example1.m', 'file'); % To force the detection of the new file under old MATLAB
 try
     data = load_m_file_data_legacy('example1.m', listofvariablestobeloaded);
-    delete('example1.m');
     t(1) = 1;
 catch
     t(1) = 0;
 end
+delete('example1.m');
 T = all(t);
 %@eof:1
 
@@ -122,15 +123,16 @@ fwriten(fid, '  f(i) = log(rand());')
 fwriten(fid, 'end');
 fclose(fid);
 % Define a set of variables to be loaded.
-listofvariablestobeloaded = {'e', 'a'};
+listofvariablestobeloaded = {'e'; 'a'};
 % Test if we can load the data.
+exist('example2.m', 'file'); % To force the detection of the new file under old MATLAB
 try
     data = load_m_file_data_legacy('example2.m', listofvariablestobeloaded);
-    delete('example2.m');
     t(1) = 0;
 catch
     t(1) = 1;
 end
+delete('example2.m');
 T = all(t);
 %@eof:2
 
@@ -149,14 +151,15 @@ fwriten(fid, '  f(i) = log(rand());')
 fwriten(fid, 'end');
 fclose(fid);
 % Define a set of variables to be loaded.
-listofvariablestobeloaded = {'c', 'a'};
+listofvariablestobeloaded = {'c'; 'a'};
 % Test if we can load the data.
+exist('example3.m', 'file'); % To force the detection of the new file under old MATLAB
 try
     data = load_m_file_data_legacy('example3.m', listofvariablestobeloaded);
-    delete('example3.m');
     t(1) = 1;
 catch
     t(1) = 0;
 end
+delete('example3.m');
 T = all(t);
 %@eof:3
