@@ -1,6 +1,6 @@
 function data  = load_mat_file_data_legacy(datafile, varobs)
 
-% Copyright (C) 2017 Dynare Team
+% Copyright (C) 2017-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -23,20 +23,20 @@ names=fieldnames(data_file);
 
 if ~all(ismember(varobs',names))
     missing_variables=varobs(~ismember(varobs',names))';
-    disp_string=[missing_variables{1,:}];
-    for ii=2:size(missing_variables,1)
-        disp_string=[disp_string,', ',missing_variables{ii,:}];
+    disp_string=[missing_variables{1}];
+    for ii=2:size(missing_variables, 2)
+        disp_string=[disp_string,', ',missing_variables{ii}];
     end
     error('makedataset: The variable(s) %s listed in varobs are not contained in the dataset %s',disp_string);
 else
     data_mat=[];
     for var_iter=1:length(varobs)
         try
-            data_mat=[data_mat vec(data_file.(varobs{1,var_iter}))];
+            data_mat=[data_mat vec(data_file.(varobs{var_iter}))];
         catch
-            error('makedataset: The variable %s does not have dimensions conformable with the previous one',varobs{1,var_iter});
+            error(['makedataset: The variable %s does not have dimensions conformable with the previous one'], varobs{var_iter});
         end
     end
 end
 
-data = dseries(data_mat,[],varobs);
\ No newline at end of file
+data = dseries(data_mat,[],varobs);
