@@ -8,7 +8,7 @@ function A = subsasgn(A,S,B) % --*-- Unitary tests --*--
 %! @end deftypefn
 %@eod:
 
-% Copyright (C) 2012-2017 Dynare Team
+% Copyright © 2012-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -25,7 +25,7 @@ function A = subsasgn(A,S,B) % --*-- Unitary tests --*--
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-merge_dseries_objects = 1;
+merge_dseries_objects = true;
 
 switch length(S)
   case 1
@@ -48,8 +48,8 @@ switch length(S)
                 error('dseries::subsasgn: (MATLAB/Octave''s regular expressions) Check opening and closing square brackets!')
             end
             % Loops and regular expressions are not compatible
-            if length(idArobase) && length(idBracket.open)
-                error(['dseries::subsasgn: You cannot use implicit loops and regular expressions in the same rule!'])
+            if ~isempty(idArobase) && ~isempty(idBracket.open)
+                error('dseries::subsasgn: You cannot use implicit loops and regular expressions in the same rule!')
             end
             if ~isempty(idArobase)
                 elements = build_list_of_variables_with_loops({}, idArobase, element, {});
@@ -76,7 +76,7 @@ switch length(S)
                     id = find(strcmp(S(1).subs{i},A.name));
                     if isempty(id)
                         % Add a new variable a change its name.
-                        B.name(i) = {S(1).subs{i}};
+                        B.name(i) = S(1).subs(i);
                         B.tex(i) = {name2tex(S(1).subs{i})};
                     else
                         % Rename variable and change its content.
@@ -130,9 +130,9 @@ switch length(S)
                     error('dseries::subsasgn: Dimension error! The number of variables on the left and right hand side must match.')
                 end
                 A.data(tdx,:) = B.data(tdy,:);
-                merge_dseries_objects = 0;
+                merge_dseries_objects = false;
             elseif isnumeric(B)
-                merge_dseries_objects = 0;
+                merge_dseries_objects = false;
                 if isequal(length(tdx),rows(B))
                     if isequal(columns(A.data),columns(B))
                         A.data(tdx,:) = B;
@@ -152,7 +152,7 @@ switch length(S)
                 A.tex = name2tex(A.name);
                 if isempty(A.dates)
                     if isempty(A.dates.freq)
-                        init = dates('1Y')
+                        init = dates('1Y');
                     else
                         init = dates(A.dates.freq, 1, 1);
                     end
@@ -174,7 +174,7 @@ switch length(S)
         error('dseries::subsasgn: Wrong syntax!')
     end
   case 2
-    merge_dseries_objects = 0;
+    merge_dseries_objects = false;
     if ((isequal(S(1).type,'{}') || isequal(S(1).type,'.')) && isequal(S(2).type,'()'))
         if isequal(S(1).type,'{}')
             sA = extract(A,S(1).subs{:});
@@ -191,7 +191,7 @@ switch length(S)
                     end
                     sA.data(tdx,:) = B.data(tdy,:);
                 elseif isnumeric(B)
-                    merge_dseries_objects = 0;
+                    merge_dseries_objects = false;
                     if isequal(length(tdx),rows(B))
                         if isequal(columns(sA.data),columns(B))
                             sA.data(tdx,:) = B;
@@ -215,7 +215,7 @@ switch length(S)
             else
                 error('dseries::subsasgn: Wrong syntax!')
             end
-            A = merge(A,sA);
+            A = merge(A, sA, true);
         else
             error('dseries::subsasgn: Dimension error! The number of variables on the left and right hand side must match.')
         end
@@ -231,7 +231,7 @@ if isempty(A)
 end
 
 if merge_dseries_objects
-    A = merge(A,B);
+    A = merge(A, B, true);
 end
 
 %@test:1
