@@ -16,7 +16,7 @@ function [freq, init, data, varlist] = load_csv_file_data(file) % --*-- Unitary
 %  names. Similarly, if the first column does not contain dates, then
 %  freq will be 1 and init will be year 1.
 
-% Copyright (C) 2012-2019 Dynare Team
+% Copyright (C) 2012-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -46,13 +46,9 @@ if isoctave
     fclose(fid);
     if length(firstline) < 4097
         if ~user_has_octave_forge_package('io')
-            try
-                pkg load io
-            catch
-                error(['The io package is required to read CSV files from Octave. ' ...
-                       'It can be installed by running the following from the Octave ' ...
-                       ' command line: pkg install -forge io']);
-            end
+            error(['The io package is required to read CSV files from Octave. ' ...
+                   'It can be installed by running the following from the Octave ' ...
+                   ' command line: pkg install -forge io']);
         end
         A = csv2cell(file);
         [data, T, L] = parsecell(A);
@@ -199,12 +195,11 @@ varlist = strrep(varlist,'"','');
 
 %@test:1
 %$ % Download csv file with data.
-%$ urlwrite('https://www.dynare.org/Datasets/data_ca1_csv.csv','data_ca1_csv.csv');
+%$ dseries_src_root = strrep(which('initialize_dseries_class'),'initialize_dseries_class.m','');
 %$
 %$ % Instantiate a dseries from the data in the csv file.
 %$ try
-%$   d = dseries('data_ca1_csv.csv');
-%$   delete('data_ca1_csv.csv');
+%$   d = dseries([ dseries_src_root '../tests/data/data_ca1_csv.csv' ]);
 %$   t(1) = true;
 %$ catch
 %$   t(1) = false;
@@ -215,4 +210,4 @@ varlist = strrep(varlist,'"','');
 %$ end
 %$
 %$ T = all(t);
-%@eof:1
\ No newline at end of file
+%@eof:1
