@@ -1,14 +1,15 @@
-function o = write(o, fid, pg, sec, row, col)
-%function o = write(o, fid, pg, sec, row, col)
+function write(o, fid, pg, sec, row, col, rep_dir)
+%function write(o, fid, pg, sec, row, col, rep_dir)
 % Write a Graph object
 %
 % INPUTS
-%   o   [graph]   graph object
-%   fid [integer] file id
-%   pg  [integer] this page number
-%   sec [integer] this section number
-%   row [integer] this row number
-%   col [integer] this col number
+%   o         [graph]   graph object
+%   fid       [integer] file id
+%   pg        [integer] this page number
+%   sec       [integer] this section number
+%   row       [integer] this row number
+%   col       [integer] this col number
+%   rep_dir   [string]  directory containing report.tex
 %
 % OUTPUTS
 %   o   [graph] graph object
@@ -16,7 +17,7 @@ function o = write(o, fid, pg, sec, row, col)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2013-2015 Dynare Team
+% Copyright (C) 2013-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -33,7 +34,6 @@ function o = write(o, fid, pg, sec, row, col)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-assert(fid ~= -1);
-o = writeGraphFile(o, pg, sec, row, col);
-fprintf(fid, '\\input{%s}', o.graphName);
+graphName = writeGraphFile(o, pg, sec, row, col, rep_dir);
+fprintf(fid, '\\input{%s}', graphName);
 end
\ No newline at end of file
