@@ -12,7 +12,7 @@ function o = addVspace(o, varargin)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2013-2015 Dynare Team
+% Copyright (C) 2013-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -29,10 +29,7 @@ function o = addVspace(o, varargin)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-assert(length(o.pages) > 0, ...
+assert(~isempty(o.pages), ...
        '@report.addVspace: Before adding a vspace, you must add a page and a section.');
-assert(length(o.pages{end}.sections) > 0, ...
-       '@report.addVspace: Before adding a vspace, you must add a section.');
-o.pages{end}.sections{end} = ...
-    o.pages{end}.sections{end}.addVspace(varargin{:});
+o.pages{end}.addVspace(varargin{:});
 end
