@@ -15,7 +15,7 @@ function plot_ms_irf(M_, options_, irf, figure_name, varlist)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2011-2017 Dynare Team
+% Copyright (C) 2011-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -40,29 +40,29 @@ nvars = M_.endo_nbr;
 endo_names = M_.endo_names;
 
 if isempty(varlist)
-    var_list = endo_names(1:M_.orig_endo_nbr,:);
+    var_list = endo_names(1:M_.orig_endo_nbr);
 end
 
 names = {};
 tex_names = {};
 m = 1;
-for i = 1:size(var_list)
-    tmp = strmatch(var_list(i,:),endo_names,'exact');
+for i = 1:length(var_list)
+    tmp = strmatch(var_list{i}, endo_names, 'exact');
     if isempty(tmp)
-        error([var_list(i,:) ' isn''t and endogenous variable'])
+        error([var_list{i} ' isn''t and endogenous variable'])
     end
-    tex_name = deblank(M_.endo_names_tex(tmp,:));
+    tex_name = M_.endo_names_tex{tmp};
     if ~isempty(tex_name)
-        names{m} = deblank(var_list(i,:));
+        names{m} = var_list{i};
         tex_names{m} = tex_name;
         m = m + 1;
     end
 end
 
 for i=1:M_.exo_nbr
-    tex_name = deblank(M_.exo_names_tex(i,:));
+    tex_name = M_.exo_names_tex{i};
     if ~isempty(tex_name)
-        names{m} = deblank(M_.exo_names(i,:));
+        names{m} = M_.exo_names{i};
         tex_names{m} = tex_name;
         m = m + 1;
     end
@@ -81,7 +81,7 @@ else
     error('The impulse response matrix passed to be plotted does not appear to be the correct size');
 end
 
-if size(endo_names,1) ~= nvars
+if length(endo_names) ~= nvars
     error('The names passed are not the same length as the number of variables');
 end
 
@@ -92,7 +92,7 @@ if num_percentiles == 1
         for i=1:nvars
             shock(:,i) = irf(:,((i-1) + ((s-1)*nvars)+1));
         end
-        plot_point_irf_for_shock(shock, nvars,endo_names, deblank(endo_names(s,:)), ...
+        plot_point_irf_for_shock(shock, nvars,endo_names, endo_names{s}, ...
                                  figure_name, [options_.ms.output_file_tag filesep 'Output' filesep 'IRF'], options_, names, tex_names);
     end
 else
@@ -103,7 +103,7 @@ else
                 shock(:,i,n) = irf(n,:,((i-1) + ((s-1)*nvars)+1));
             end
         end
-        plot_banded_irf_for_shock(shock, nvars,endo_names, deblank(endo_names(s,:)), ...
+        plot_banded_irf_for_shock(shock, nvars,endo_names, endo_names{s}, ...
                                   figure_name, [options_.ms.output_file_tag filesep 'Output' filesep 'IRF'], options_, names, tex_names);
     end
 end
@@ -114,8 +114,8 @@ fig = figure('Name',figure_name);
 for k=1:nvars
     subplot(ceil(sqrt(nvars)), ceil(sqrt(nvars)),k);
     plot(irf(:,k))
-    disp([endo_names(k,:) ' shock from ' shock_name]);
-    title([endo_names(k,:) ' shock from ' shock_name]);
+    disp([endo_names{k} ' shock from ' shock_name]);
+    title([endo_names{k} ' shock from ' shock_name]);
 end
 dyn_save_graph(dirname,[figure_name ' ' shock_name],options_.graph_save_formats, ...
                options_.TeX,names,tex_names,[figure_name ' ' shock_name]);
@@ -131,8 +131,8 @@ for k=1:nvars
         hold on
     end
     hold off
-    disp([endo_names(k,:) ' shock from ' shock_name]);
-    title([endo_names(k,:) ' shock from ' shock_name]);
+    disp([endo_names{k} ' shock from ' shock_name]);
+    title([endo_names{k} ' shock from ' shock_name]);
 end
 dyn_save_graph(dirname,[figure_name ' ' shock_name],options_.graph_save_formats, ...
                options_.TeX,names,tex_names,[figure_name ' ' shock_name]);
