@@ -12,7 +12,7 @@ function perfect_foresight_setup()
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 1996-2017 Dynare Team
+% Copyright (C) 1996-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -34,13 +34,13 @@ global M_ options_ oo_
 test_for_deep_parameters_calibration(M_);
 
 if size(M_.lead_lag_incidence,2)-nnz(M_.lead_lag_incidence(M_.maximum_endo_lag+1,:)) > 0
-    mess = ['PERFECT_FORESIGHT_SETUP: error in model specification : the variable(s) '];
-    var_list=M_.endo_names(find(M_.lead_lag_incidence(M_.maximum_lag+1,:)==0),:);
-    for i=1:size(var_list,1)
-        if i<size(var_list,1)
-            mess = [mess, deblank(var_list(i,:)) ', '];
+    mess = 'PERFECT_FORESIGHT_SETUP: error in model specification : the variable(s) ';
+    var_list = M_.endo_names(M_.lead_lag_incidence(M_.maximum_endo_lag+1,:)==0);
+    for i=1:length(var_list)
+        if i<length(var_list)
+            mess = [mess, var_list{i} ', '];
         else
-            mess = [mess, deblank(var_list(i,:)) ];
+            mess = [mess, var_list{i} ];
         end
     end
     mess = [mess ' don''t appear as current period variables.'];
@@ -55,8 +55,8 @@ if ~isempty(M_.det_shocks) && options_.periods<max([M_.det_shocks.periods])
     % Some expected shocks happen after the terminal period.
     mess = sprintf('Problem with the declaration of the expected shocks:\n');
     for i=1:length(M_.det_shocks)
-        if any(M_.det_shocks(i).periods>options_.periods);
-            mess = sprintf('%s\n   At least one expected value for %s has been declared after the terminal period.', mess, deblank(M_.exo_names(M_.det_shocks(i).exo_id,:)));
+        if any(M_.det_shocks(i).periods>options_.periods)
+            mess = sprintf('%s\n   At least one expected value for %s has been declared after the terminal period.', mess, M_.exo_names{M_.det_shocks(i).exo_id});
         end
     end
     disp(mess)
@@ -65,10 +65,6 @@ if ~isempty(M_.det_shocks) && options_.periods<max([M_.det_shocks.periods])
 end
 
 if ~options_.initval_file
-    if isempty(options_.datafile)
-        oo_=make_ex_(M_,options_,oo_);
-        oo_=make_y_(M_,options_,oo_);
-    else
-        read_data_;
-    end
+    oo_ = make_ex_(M_,options_,oo_);
+    oo_ = make_y_(M_,options_,oo_);
 end
