@@ -1,4 +1,4 @@
-function [post_mean, post_median, post_var, hpd_interval, post_deciles, density] = posterior_moments(xx,info,mh_conf_sig)
+function [post_mean, post_median, post_var, hpd_interval, post_deciles, density] = posterior_moments(xx,info,mh_conf_sig,kernel_options)
 % Computes posterior mean, median, variance, HPD interval, deciles, and density from posterior draws.
 %
 % INPUTS
@@ -11,17 +11,17 @@ function [post_mean, post_median, post_var, hpd_interval, post_deciles, density]
 %    post_mean     [double]    Scalar, posterior mean.
 %    post_median   [double]    Scalar, posterior median.
 %    post_var      [double]    Scalar, posterior variance.
-%    hpd_interval  [double]    Vector (1*2), Highest Probability Density interval 
+%    hpd_interval  [double]    Vector (1*2), Highest Probability Density interval
 %    post_deciles  [double]    Vector (9*1), deciles of the posterior distribution.
-%    density       [double]    Matrix (n*2), non parametric estimate of the posterior density. First and second 
-%                              columns are respectively abscissa and ordinate coordinates.  
-%    
+%    density       [double]    Matrix (n*2), non parametric estimate of the posterior density. First and second
+%                              columns are respectively abscissa and ordinate coordinates.
+%
 % SPECIAL REQUIREMENTS
-%    Other matlab routines distributed with Dynare: mh_optimal_bandwidth.m 
+%    Other matlab routines distributed with Dynare: mh_optimal_bandwidth.m
 %                                                   kernel_density_estimate.m.
 %
 
-% Copyright (C) 2005-2011 Dynare Team
+% Copyright (C) 2005-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -38,6 +38,16 @@ function [post_mean, post_median, post_var, hpd_interval, post_deciles, density]
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
+if nargin<4
+    number_of_grid_points = 2^9;      % 2^9 = 512 !... Must be a power of two.
+    bandwidth = 0;                    % Rule of thumb optimal bandwidth parameter.
+    kernel_function = 'gaussian';     % Gaussian kernel for Fast Fourrier Transform approximaton.
+else
+    number_of_grid_points = kernel_options.gridpoints;
+    bandwidth = kernel_options.bandwidth;
+    kernel_function = kernel_options.kernel_function;
+end
+
 xx = xx(:);
 xx = sort(xx);
 
@@ -59,7 +69,7 @@ if hpd_draws>2
     [kmin,idx] = min(kk);
     hpd_interval = [xx(idx) xx(idx)+kmin];
 else
-    hpd_interval=NaN(1,2);    
+    hpd_interval=NaN(1,2);
 end
 if length(xx)>9
     post_deciles = xx([round(0.1*number_of_draws) ...
@@ -76,10 +86,7 @@ else
 end
 density = [];
 if info
-    number_of_grid_points = 2^9;      % 2^9 = 512 !... Must be a power of two.
     if post_var > 1e-12
-        bandwidth = 0;                    % Rule of thumb optimal bandwidth parameter.
-        kernel_function = 'gaussian';     % Gaussian kernel for Fast Fourrier Transform approximaton.  
         optimal_bandwidth = mh_optimal_bandwidth(xx,number_of_draws,bandwidth,kernel_function);
         [density(:,1),density(:,2)] = kernel_density_estimate(xx,number_of_grid_points,...
                                                           number_of_draws,optimal_bandwidth,kernel_function);
