@@ -92,9 +92,9 @@ for i=1:length(p6)
                 bounds.lb(i) = gaminv(prior_trunc,p6(i),p7(i))+p3(i);
                 bounds.ub(i) = gaminv(1-prior_trunc,p6(i),p7(i))+p3(i);
             catch
-                % Workaround for ticket #161
+                % Workaround for ticket #161, see http://savannah.gnu.org/bugs/?52569
                 if isoctave
-                    error(['Due to a bug in Octave, you must choose other values for mean and/or variance of your prior on ' bayestopt.name{i} ', or use another shape'])
+                    error(['Due to a computational limitation in Octave, the prior bounds cannot be computed. You must either use prior_trunc=0 or choose other values for mean and/or variance of your prior on ' bayestopt.name{i} ', or use another shape'])
                 else
                     rethrow(lasterror)
                 end
@@ -117,9 +117,9 @@ for i=1:length(p6)
                 bounds.lb(i) = 1/sqrt(gaminv(1-prior_trunc, p7(i)/2, 2/p6(i)))+p3(i);
                 bounds.ub(i) = 1/sqrt(gaminv(prior_trunc, p7(i)/2, 2/p6(i)))+p3(i);
             catch
-                % Workaround for ticket #161
+                % Workaround for ticket #161, see http://savannah.gnu.org/bugs/?52569
                 if isoctave
-                    error(['Due to a bug in Octave, you must choose other values for mean and/or variance of your prior on ' bayestopt.name{i} ', or use another shape'])
+                    error(['Due to a computational limitation in Octave, the prior bounds cannot be computed. You must either use prior_trunc=0 or choose other values for mean and/or variance of your prior on ' bayestopt.name{i} ', or use another shape'])
                 else
                     rethrow(lasterror)
                 end
@@ -142,9 +142,9 @@ for i=1:length(p6)
                 bounds.lb(i) = 1/gaminv(1-prior_trunc, p7(i)/2, 2/p6(i))+p3(i);
                 bounds.ub(i) = 1/gaminv(prior_trunc, p7(i)/2, 2/p6(i))+ p3(i);
             catch
-                % Workaround for ticket #161
+                % Workaround for ticket #161, see http://savannah.gnu.org/bugs/?52569
                 if isoctave
-                    error(['Due to a bug in Octave, you must choose other values for mean and/or variance of your prior on ' bayestopt.name{i} ', or use another shape'])
+                    error(['Due to a computational limitation in Octave, the prior bounds cannot be computed. You must either use prior_trunc=0 or choose other values for mean and/or variance of your prior on ' bayestopt.name{i} ', or use another shape'])
                 else
                     rethrow(lasterror)
                 end
