@@ -12,7 +12,7 @@ function z = resid(junk)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2001-2017 Dynare Team
+% Copyright (C) 2001-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -56,7 +56,7 @@ if any(imag(oo_.steady_state))
     if ~isempty(imagrow)
         fprintf('\nresid: The initial values for the steady state of the following variables are complex:\n');
         for iter=1:length(imagrow)
-            fprintf('%s\n',M_.endo_names(imagrow(iter),:));
+            fprintf('%s\n', M_.endo_names{imagrow(iter)});
         end
     end
 end
@@ -70,7 +70,7 @@ end
 if options_.block && ~options_.bytecode
     z = zeros(M_.endo_nbr,1);
     for i = 1:length(M_.block_structure_stat.block)
-        [r, g, yy, var_indx] = feval([M_.fname '_static'],...
+        [r, g, yy, var_indx] = feval([M_.fname '.static'],...
                                      i,...
                                      oo_.steady_state,...
                                      [oo_.exo_steady_state; ...
@@ -82,7 +82,7 @@ elseif options_.bytecode
     [check, z] = bytecode('evaluate','static');
     mexErrCheck('bytecode', check);
 else
-    z = feval([M_.fname '_static'],...
+    z = feval([M_.fname '.static'],...
               oo_.steady_state,...
               [oo_.exo_steady_state; ...
                oo_.exo_det_steady_state], M_.params);
@@ -98,7 +98,7 @@ if nargout == 0
     disp('Residuals of the static equations:')
     skipline()
     for i=1:M_.orig_endo_nbr
-        if abs(z(i)) < options_.dynatol.f/100
+        if abs(z(i)) < options_.solve_tolf/100
             tmp = 0;
         else
             tmp = z(i);
