@@ -1,9 +1,9 @@
 function S = shiftS(S,n)
-%function S = shiftS(S)
+%function S = shiftS(S,n)
 %
-% Removes the first element of a one dimensional cell array.
+% Removes the first n elements of a one dimensional cell array.
 
-% Copyright (C) 2013 Dynare Team
+% Copyright (C) 2013-2014 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -20,18 +20,9 @@ function S = shiftS(S,n)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-if nargin<2
-    n = 1;
-end
-    
-if length(S) > 1
-    S = S(2:end);
-    n = n-1;
+if length(S) >= n+1
+    S = S(n+1:end);
 else
     S = {};
-    n = 0;
 end
-
-if n
-    S = shiftS(S,n);
 end
\ No newline at end of file
