@@ -42,7 +42,7 @@ function [Gamma_y,stationary_vars] = th_autocovariances(dr,ivar,M_,options_,node
 %   E(x_t) = (I - {g_x}\right)^{- 1} 0.5\left( g_{\sigma\sigma} \sigma^2 + g_{xx} Var(\hat x_t) + g_{uu} Var(u_t) \right)
 %   \]
 %
-% Copyright (C) 2001-2017 Dynare Team
+% Copyright (C) 2001-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -68,7 +68,7 @@ if options_.order >= 3
 end
 
 local_order = options_.order;
-if M_.hessian_eq_zero && local_order~=1
+if local_order~=1 && M_.hessian_eq_zero
     local_order = 1;
 end
 
@@ -92,7 +92,7 @@ nspred = M_.nspred;
 nstatic = M_.nstatic;
 
 nx = size(ghx,2);
-if options_.block == 0
+if ~options_.block
     %order_var = dr.order_var;
     inv_order_var = dr.inv_order_var;
     kstate = dr.kstate;
@@ -123,7 +123,7 @@ end
 b = ghu1*M_.Sigma_e*ghu1';
 
 
-if options_.block == 0
+if ~options_.block
     ipred = nstatic+(1:nspred)';
 else
     ipred = dr.state_var;
@@ -135,7 +135,7 @@ end
 % HP filtering, this mean correction is computed *before* filtering)
 if local_order == 2 || options_.hp_filter == 0
     [vx, u] =  lyapunov_symm(A,B*M_.Sigma_e*B',options_.lyapunov_fixed_point_tol,options_.qz_criterium,options_.lyapunov_complex_threshold,[],options_.debug);
-    if options_.block == 0
+    if ~options_.block
         iky = inv_order_var(ivar);
     else
         iky = ivar;
@@ -220,7 +220,7 @@ else% ==> Theoretical filters.
     bb = ghu(iky,:); %S in Uhlig (2001)
 
     lambda = options_.hp_filter;
-    ngrid = options_.hp_ngrid;
+    ngrid = options_.filtered_theoretical_moments_grid;
     freqs = 0 : ((2*pi)/ngrid) : (2*pi*(1 - .5/ngrid)); %[0,2*pi)
     tpos  = exp( sqrt(-1)*freqs); %positive frequencies
     tneg  =  exp(-sqrt(-1)*freqs); %negative frequencies
