@@ -1,4 +1,4 @@
-function [m,s,p6,p7] = uniform_specification(m,s,p3,p4)
+function [m,s,p6,p7,error_indicator] = uniform_specification(m,s,p3,p4)
 % Specification of the uniform density function parameters
 %
 % INPUTS
@@ -10,8 +10,9 @@ function [m,s,p6,p7] = uniform_specification(m,s,p3,p4)
 % OUTPUTS
 %    m:      mean
 %    s:      standard deviation
-%    p1:     lower bound
-%    p2:     upper bound
+%    p6:     lower bound
+%    p7:     upper bound
+%    error_indicator:   whether inconsistent prior specification was used
 %
 % SPECIAL REQUIREMENTS
 %    none
@@ -32,13 +33,17 @@ function [m,s,p6,p7] = uniform_specification(m,s,p3,p4)
 %
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
-
+error_indicator=0;
 if ~(isnan(p3) || isnan(p4))
     p6 = p3;
     p7 = p4;
+    if ~isnan(m) || ~isnan(s)
+        error_indicator=1;
+    end
     m  = (p3+p4)/2;
     s  = (p4-p3)/(sqrt(12));
 else
     p6 = m-s*sqrt(3);
     p7 = m+s*sqrt(3);
+
 end
\ No newline at end of file
