@@ -6,8 +6,9 @@ function [DynareDataset, DatasetInfo, newdatainterface] = makedataset(DynareOpti
 % INPUTS
 % ======
 %
-%     DynareOptions [struct] Structure of options built by Dynare's preprocessor.
-%
+%     DynareOptions         [struct]    Structure of options built by Dynare's preprocessor.
+%     initialconditions     [double]    number of lags for VAR and DSGE_VAR
+%     gsa_flag              [integer]   1: GSA, 0: other
 %
 % OUTPUTS
 % =======
@@ -23,7 +24,7 @@ function [DynareDataset, DatasetInfo, newdatainterface] = makedataset(DynareOpti
 %
 % See also dynare_estimation_init
 
-% Copyright (C) 2014-2017 Dynare Team
+% Copyright (C) 2014-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -39,7 +40,7 @@ function [DynareDataset, DatasetInfo, newdatainterface] = makedataset(DynareOpti
 %
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
-    
+
 
 if nargin<3
     gsa_flag = 0;
@@ -266,7 +267,7 @@ else
 end
 
 % Compute the empirical mean of the observed variables.
-DatasetInfo.descriptive.mean = nanmean(DynareDataset.data);
+DatasetInfo.descriptive.mean = nanmean(DynareDataset.data,1);
 
 % Compute the empirical covariance matrix of the observed variables.
 DatasetInfo.descriptive.covariance = nancovariance(DynareDataset.data);
