@@ -10,7 +10,7 @@ function writedata(fname)
 % SPECIAL REQUIREMENT
 %   none
 
-% Copyright (C) 2007-2017 Dynare Team
+% Copyright (C) 2007-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -36,7 +36,7 @@ end
 S=[fname '_endo.xls'];
 n=size(oo_.endo_simul,2);
 delete(S);
-S=upper(cellstr(M_.endo_names));
+S=upper(M_.endo_names);
 S1=cellstr([num2str((1:n)')  char(65*ones(1,n))']);
 xlswrite([fname '_endo'], S', 'endogenous', 'B1');
 xlswrite([fname '_endo'], S1, 'endogenous', 'A2');
@@ -44,7 +44,7 @@ xlswrite([fname '_endo'], oo_.endo_simul', 'endogenous', 'B2');
 S=[fname '_exo.xls'];
 n=size(oo_.exo_simul,1);
 delete(S);
-S=upper(cellstr(M_.exo_names));
+S=upper(M_.exo_names);
 S1=cellstr([num2str((1:n)')  char(65*ones(1,n))']);
 xlswrite([fname '_exo'], S','exogenous', 'B1');
 xlswrite([fname '_exo'], S1, 'exogenous', 'A2');
