@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2017 Dynare Team
+ * Copyright © 2007-2019 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -18,58 +18,54 @@
  */
 
 /*
- * This mex file computes A*kron(B,C) or A*kron(B,B) without explicitly building kron(B,C) or kron(B,B), so that
- * one can consider large matrices A, B and/or C, and assuming that A is a the hessian of a dsge model
- * (dynare format). This mex file should not be used outside dr1.m.
+ * This mex file computes A·(B⊗C) or A·(B⊗B) without explicitly building B⊗C or B⊗B, so that
+ * one can consider large matrices A, B and/or C, and assuming that A is a the hessian of a DSGE model
+ * (dynare format). This mex file should not be used outside dyn_second_order_solver.m.
  */
 
-#include <string.h>
+#include <algorithm>
 
 #include <dynmex.h>
 
-#ifdef USE_OMP
-# include <omp.h>
-#endif
+#include <omp.h>
 
 #define DEBUG_OMP 0
 
 void
-sparse_hessian_times_B_kronecker_B(mwIndex *isparseA, mwIndex *jsparseA, double *vsparseA,
-                                   double *B, double *D, mwSize mA, mwSize nA, mwSize mB, mwSize nB, int number_of_threads)
+sparse_hessian_times_B_kronecker_B(const mwIndex *isparseA, const mwIndex *jsparseA, const double *vsparseA,
+                                   const double *B, double *D, size_t mA, size_t nA, size_t mB, size_t nB, int number_of_threads)
 {
   /*
-  **   Loop over the columns of kron(B,B) (or of the result matrix D).
+  **   Loop over the columns of B⊗B (or of the result matrix D).
   **   This loop is splitted into two nested loops because we use the
   **   symmetric pattern of the hessian matrix.
   */
-#if USE_OMP
-# pragma omp parallel for num_threads(number_of_threads)
-#endif
-  for (mwIndex j1B = 0; j1B < nB; j1B++)
+#pragma omp parallel for num_threads(number_of_threads)
+  for (mwIndex j1B = 0; j1B < static_cast<mwIndex>(nB); j1B++)
     {
 #if DEBUG_OMP
       mexPrintf("%d thread number is %d (%d).\n", j1B, omp_get_thread_num(), omp_get_num_threads());
 #endif
-      for (mwIndex j2B = j1B; j2B < nB; j2B++)
+      for (mwIndex j2B = j1B; j2B < static_cast<mwIndex>(nB); j2B++)
         {
-          mwIndex jj = j1B*nB+j2B; // column of kron(B,B) index.
+          mwIndex jj = j1B*nB+j2B; // column of B⊗B index.
           mwIndex iv = 0;
           int nz_in_column_ii_of_A = 0;
           mwIndex k1 = 0;
           mwIndex k2 = 0;
           /*
-          ** Loop over the rows of kron(B,B) (column jj).
+          ** Loop over the rows of B⊗B (column jj).
           */
-          for (mwIndex ii = 0; ii < nA; ii++)
+          for (mwIndex ii = 0; ii < static_cast<mwIndex>(nA); ii++)
             {
               k1 = jsparseA[ii];
               k2 = jsparseA[ii+1];
               if (k1 < k2) // otherwise column ii of A does not have non zero elements (and there is nothing to compute).
                 {
                   ++nz_in_column_ii_of_A;
-                  mwIndex i1B = (ii/mB);
-                  mwIndex i2B = (ii%mB);
-                  double bb  = B[j1B*mB+i1B]*B[j2B*mB+i2B];
+                  mwIndex i1B = ii / mB;
+                  mwIndex i2B = ii % mB;
+                  double bb = B[j1B*mB+i1B]*B[j2B*mB+i2B];
                   /*
                   ** Loop over the non zero entries of A(:,ii).
                   */
@@ -82,25 +78,21 @@ sparse_hessian_times_B_kronecker_B(mwIndex *isparseA, mwIndex *jsparseA, double
                 }
             }
           if (nz_in_column_ii_of_A > 0)
-            {
-              memcpy(&D[(j2B*nB+j1B)*mA], &D[jj*mA], mA*sizeof(double));
-            }
+            std::copy_n(&D[jj*mA], mA, &D[(j2B*nB+j1B)*mA]);
         }
     }
 }
 
 void
-sparse_hessian_times_B_kronecker_C(mwIndex *isparseA, mwIndex *jsparseA, double *vsparseA,
-                                   double *B, double *C, double *D,
-                                   mwSize mA, mwSize nA, mwSize mB, mwSize nB, mwSize mC, mwSize nC, int number_of_threads)
+sparse_hessian_times_B_kronecker_C(const mwIndex *isparseA, const mwIndex *jsparseA, const double *vsparseA,
+                                   const double *B, const double *C, double *D,
+                                   size_t mA, size_t nA, size_t mB, size_t nB, size_t mC, size_t nC, int number_of_threads)
 {
   /*
-  **   Loop over the columns of kron(B,B) (or of the result matrix D).
+  **   Loop over the columns of B⊗B (or of the result matrix D).
   */
-#if USE_OMP
-# pragma omp parallel for num_threads(number_of_threads)
-#endif
-  for (mwIndex jj = 0; jj < nB*nC; jj++) // column of kron(B,C) index.
+#pragma omp parallel for num_threads(number_of_threads)
+  for (mwIndex jj = 0; jj < static_cast<mwIndex>(nB*nC); jj++) // column of B⊗C index.
     {
       // Uncomment the following line to check if all processors are used.
 #if DEBUG_OMP
@@ -113,17 +105,17 @@ sparse_hessian_times_B_kronecker_C(mwIndex *isparseA, mwIndex *jsparseA, double
       mwIndex iv = 0;
       int nz_in_column_ii_of_A = 0;
       /*
-      ** Loop over the rows of kron(B,C) (column jj).
+      ** Loop over the rows of B⊗C (column jj).
       */
-      for (mwIndex ii = 0; ii < nA; ii++)
+      for (mwIndex ii = 0; ii < static_cast<mwIndex>(nA); ii++)
         {
           k1 = jsparseA[ii];
           k2 = jsparseA[ii+1];
           if (k1 < k2) // otherwise column ii of A does not have non zero elements (and there is nothing to compute).
             {
               ++nz_in_column_ii_of_A;
-              mwIndex iC = (ii%mB);
-              mwIndex iB = (ii/mB);
+              mwIndex iC = ii % mB;
+              mwIndex iB = ii / mB;
               double cb = C[jC*mC+iC]*B[jB*mB+iB];
               /*
               ** Loop over the non zero entries of A(:,ii).
@@ -143,63 +135,56 @@ void
 mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 {
   // Check input and output:
-  if ((nrhs > 4) || (nrhs < 3))
+  if (nrhs > 4 || nrhs < 3)
     DYN_MEX_FUNC_ERR_MSG_TXT("sparse_hessian_times_B_kronecker_C takes 3 or 4 input arguments and provides 2 output arguments.");
 
   if (!mxIsSparse(prhs[0]))
     DYN_MEX_FUNC_ERR_MSG_TXT("sparse_hessian_times_B_kronecker_C: First input must be a sparse (dynare) hessian matrix.");
 
   // Get & Check dimensions (columns and rows):
-  mwSize mA, nA, mB, nB, mC, nC;
-  mA = mxGetM(prhs[0]);
-  nA = mxGetN(prhs[0]);
-  mB = mxGetM(prhs[1]);
-  nB = mxGetN(prhs[1]);
-  if (nrhs == 4) // A*kron(B,C) is to be computed.
+  size_t mA = mxGetM(prhs[0]);
+  size_t nA = mxGetN(prhs[0]);
+  size_t mB = mxGetM(prhs[1]);
+  size_t nB = mxGetN(prhs[1]);
+  size_t mC, nC;
+  if (nrhs == 4) // A·(B⊗C) is to be computed.
     {
       mC = mxGetM(prhs[2]);
       nC = mxGetN(prhs[2]);
       if (mB*mC != nA)
         DYN_MEX_FUNC_ERR_MSG_TXT("Input dimension error!");
     }
-  else // A*kron(B,B) is to be computed.
+  else // A·(B⊗B) is to be computed.
     {
       if (mB*mB != nA)
         DYN_MEX_FUNC_ERR_MSG_TXT("Input dimension error!");
     }
   // Get input matrices:
-  double *B, *C;
   int numthreads;
-  B = mxGetPr(prhs[1]);
-  numthreads = (int) mxGetScalar(prhs[2]);
+  const double *B = mxGetPr(prhs[1]);
+  const double *C;
+  numthreads = static_cast<int>(mxGetScalar(prhs[2]));
   if (nrhs == 4)
     {
       C = mxGetPr(prhs[2]);
-      numthreads = (int) mxGetScalar(prhs[3]);
+      numthreads = static_cast<int>(mxGetScalar(prhs[3]));
     }
   // Sparse (dynare) hessian matrix.
-  mwIndex *isparseA = (mwIndex *) mxGetIr(prhs[0]);
-  mwIndex *jsparseA = (mwIndex *) mxGetJc(prhs[0]);
-  double  *vsparseA = mxGetPr(prhs[0]);
+  const mwIndex *isparseA = mxGetIr(prhs[0]);
+  const mwIndex *jsparseA = mxGetJc(prhs[0]);
+  const double *vsparseA = mxGetPr(prhs[0]);
   // Initialization of the ouput:
-  double *D;
   if (nrhs == 4)
-    {
-      plhs[0] = mxCreateDoubleMatrix(mA, nB*nC, mxREAL);
-    }
+    plhs[0] = mxCreateDoubleMatrix(mA, nB*nC, mxREAL);
   else
-    {
-      plhs[0] = mxCreateDoubleMatrix(mA, nB*nB, mxREAL);
-    }
-  D = mxGetPr(plhs[0]);
+    plhs[0] = mxCreateDoubleMatrix(mA, nB*nB, mxREAL);
+  double *D = mxGetPr(plhs[0]);
+
   // Computational part:
   if (nrhs == 3)
-    {
-      sparse_hessian_times_B_kronecker_B(isparseA, jsparseA, vsparseA, B, D, mA, nA, mB, nB, numthreads);
-    }
+    sparse_hessian_times_B_kronecker_B(isparseA, jsparseA, vsparseA, B, D, mA, nA, mB, nB, numthreads);
   else
-    {
-      sparse_hessian_times_B_kronecker_C(isparseA, jsparseA, vsparseA, B, C, D, mA, nA, mB, nB, mC, nC, numthreads);
-    }
+    sparse_hessian_times_B_kronecker_C(isparseA, jsparseA, vsparseA, B, C, D, mA, nA, mB, nB, mC, nC, numthreads);
+
   plhs[1] = mxCreateDoubleScalar(0);
 }
