@@ -74,7 +74,7 @@ ModelTree::copyHelper(const ModelTree &m)
   for (const auto &it : m.temporary_terms)
     temporary_terms.insert(f(it));
   for (const auto &it : m.temporary_terms_mlv)
-    temporary_terms_mlv[f(it.first)] = f(it.second);
+    temporary_terms_mlv[dynamic_cast<VariableNode *>(f(it.first))] = f(it.second);
   for (const auto &it : m.temporary_terms_derivatives)
     temporary_terms_derivatives.push_back(convert_temporary_terms_t(it));
   for (const auto &it : m.temporary_terms_idxs)
@@ -1367,6 +1367,8 @@ ModelTree::writeModelLocalVariableTemporaryTerms(temporary_terms_t &temp_term_un
 
   for (auto &it : temporary_terms_mlv)
     {
+      it.second->writeExternalFunctionOutput(output, output_type, temp_term_union, tt_idxs, tef_terms);
+
       if (isJuliaOutput(output_type))
         output << "    @inbounds const ";
 
@@ -1614,7 +1616,7 @@ ModelTree::compileTemporaryTerms(ostream &code_file, unsigned int &instruction_n
 }
 
 void
-ModelTree::writeJsonModelLocalVariables(ostream &output, deriv_node_temp_terms_t &tef_terms) const
+ModelTree::writeJsonModelLocalVariables(ostream &output, bool write_tef_terms, deriv_node_temp_terms_t &tef_terms) const
 {
   /* Collect all model local variables appearing in equations, and print only
      them. Printing unused model local variables can lead to a crash (see
@@ -1638,23 +1640,24 @@ ModelTree::writeJsonModelLocalVariables(ostream &output, deriv_node_temp_terms_t
           printed = true;
 
         int id = it;
-        vector<string> efout;
         expr_t value = local_variables_table.find(id)->second;
-        value->writeJsonExternalFunctionOutput(efout, tt, tef_terms);
-        for (auto it1 = efout.begin(); it1 != efout.end(); ++it1)
+        if (write_tef_terms)
           {
-            if (it1 != efout.begin())
+            vector<string> efout;
+            value->writeJsonExternalFunctionOutput(efout, tt, tef_terms);
+            for (auto it1 = efout.begin(); it1 != efout.end(); ++it1)
+              {
+                if (it1 != efout.begin())
+                  output << ", ";
+                output << *it1;
+              }
+
+            if (!efout.empty())
               output << ", ";
-            output << *it1;
           }
 
-        if (!efout.empty())
-          output << ", ";
-
-        /* We append underscores to avoid name clashes with "g1" or "oo_" (see
-           also VariableNode::writeOutput) */
-        output << R"({"variable": ")" << symbol_table.getName(id) << R"(__")"
-               << R"(, "value": ")";
+        output << R"({"variable": ")" << symbol_table.getName(id)
+               << R"(", "value": ")";
         value->writeJsonOutput(output, tt, tef_terms);
         output << R"("})" << endl;
       }
